*      
      SUBROUTINE NASA(IZT,IAT,IZP,IAP,EIN,SIGTOT,SIGNON)
*
*     CALCULATION OF TOTAL AND REACTION CROSS SECTIONS
*     FOR NEUTRON AND PROTON BY NASA SYSTEMATICS
*       REF. R.K. TRIPATHI, F.A. CUCINOTTA AND J.W. WILSON;
*               NASA TECHNICAL PAPER 3621 (1997).
*            R.K. TRIPATHI, F.A. CUCINOTTA AND J.W. WILSON;
*               NASA/TP-1998-208438 (1998).
*
*     VALIUABLES
*       IZT: ATOMIC MUMBER OF TARGET
*       IAT: MASS NUMBER OF TARGET
*       IZP: ATOMIC MUMBER OF PROJECTILE
*       IAP: MASS NUMBER OF PROJECTILE
*       EIN: INCIDENT ENERGY [MEV]
*       SIGTOT: TOTAL CROSS SECTION [B]
*       SIGNON: NON-ELASTIC CROSS SECTION [B]
*
      ZP=FLOAT(IZP)
      AP=FLOAT(IAP)
      ZT=FLOAT(IZT)
      AT=FLOAT(IAT)
*
      SIGNON=XABS(ZP,AP,ZT,AT,EIN)*1.0E-3
      SIGTOT=SIGNON*(1.45+(EIN-250.0)*0.0001)
*
      RETURN
      END
*
      FUNCTION XABS(ZP,AP,ZT,AT,E)	
C ABSOPRPTION XSEC REVISED VERSION RKT-97/4
C NEUTRON DATA FROM BARASHENKOV
C THIS GIVES ABSORPTION XSEC FOR GIVEN ZP,AP,ZT,AT,E (MeV/NUCLEON)
C CAN BE USED FOR NEUTRONS ALSO.
C     THIS HAS COULOMB AS OURS
      XQ1 = ZP
      XQ2 = AP	
      XQ3 = ZT
      XQ4 = AT	
C
C NUCLEON-NUCLEON INELASTC XSEC NOT INCLUDED HERE
C
      IF(IFIX(ZP*ZT).EQ.1.OR.IFIX(ZP+ZT).EQ.1) THEN
      XABS=0.
      RETURN
      ENDIF			 	
      PI = 3.141592654
      RP = RADIUS (AP)
      RT = RADIUS (AT)
      VP =  (4./3)*PI*RP**3
      VT =  (4./3.)*PI*RT**3
      DENSITY = 0.5*((AP/VP)+(AT/VT)) 
      CONST= 1.75*DENSITY/8.824728E-02
      IF(ZT.LT.ZP) THEN
      XZT=ZP
      XAT=AP
      ZP=ZT
      AP=AT
      ZT=XZT
      AT=XAT
      ENDIF	
      IF (IFIX(AP).EQ.1) CONST = 2.05
      IF(IFIX(ZP).EQ.2.AND.IFIX(AP).EQ.4) THEN
      CONST1= 2.77 - AT*8.0E-03+(AT*AT)*1.8E-05
      ENDIF	
      IF (IFIX(ZP).EQ.3) CONST= CONST/3.  
      T1 = 40
      IF(IFIX(ZP).EQ.0) THEN	
      IF(AT.GE.11.AND.AT.LT.40) T1 =30
      IF (IFIX(ZT).EQ.14) T1 = 35.
      IF (IFIX(ZT).EQ.26) T1 = 30.
      ENDIF	
      GCM=(AP*(1.+E/938.)+AT)/(AP**2+AT**2+2.*AP*(E+938.)*AT/938.
     -)**.5
      BCM=SQRt(1.-1./GCM**2)
      PLAB=AP*SQRt(2.*938.*E+E*E)
      ECMP=GCM*(E+938.)*AP-BCM*GCM*PLAB-AP*938.
      ECMT=GCM*938.*AT-AT*938.
      RELA=ECMP+ECMT
      ECM=RELA
      IF(ECM.LT..1*RELA)ECM=.1*RELA
      RM=(197.32/137.01)*ZP*ZT/ECM
      BIGR=RP+RT+1.2*(AP**(1./3.)+AT**(1./3.))/(ECM**(1./3.))
      BIGB = 1.44*ZP*ZT/BIGR
      IF(IFIX(ZP).EQ.1.AND.IFIX(AT).GT.56) BIGB= 0.90*BIGB 
      IF(IFIX(AP).GT.56.AND.IFIX(ZT).EQ.1) BIGB= 0.90*BIGB 
      IF(IFIX(AP).EQ.1.AND.IFIX(AT).EQ.12) BIGB= 3.5*BIGB
      IF(IFIX(AP).EQ.1) THEN
      IF(IFIX(AT).LE.16.AND.IFIX(AT).GE.13) THEN
      BIGB = (AT/7.)*BIGB
      ENDIF		
      IF ( IFIX(ZT).EQ.12) BIGB = 1.8*BIGB    
      IF ( IFIX(ZT).EQ.14) BIGB = 1.4*BIGB    
      IF ( IFIX(ZT).EQ.20) BIGB = 1.3*BIGB    
      ENDIF		
      IF (IFIX(AP).EQ.1.AND.IFIX(AT).LT.4) BIGB=21.0*BIGB
      IF (IFIX(AP).LT.4.AND.IFIX(AT).EQ.1) BIGB=21.0*BIGB
      IF(IFIX(AP).EQ.1.AND.IFIX(AT).EQ.4) BIGB= 27.0*BIGB 
      IF(IFIX(AP).EQ.4.AND.IFIX(AT).EQ.1) BIGB= 27.0*BIGB
      IF(IFIX(ZP).EQ.0.OR.IFIX(ZT).EQ.0)BIGB=0.0	
      XSEC = 10*PI*BIGR*BIGR*(1.- BIGB/ECM)			
      XM=1.      
      IF(IFIX(ZP).EQ.0) THEN	
      IF( AT.LT.200.) THEN
      X1 = 2.83 -3.1E-02*AT+1.7E-04*AT*AT 
      IF(X1.LE.1) X1 =1.	
      SL = 1.0
      IF(AT.EQ.12) SL=1.6
      IF(AT.LT.12) SL= 0.6
      XM = (1-X1*EXP(-E/(SL*X1)))  
c     IF(E.LT.20) PRINT*,'E,XM=',E,XM
      ELSE
      XM =( 1 - 0.3*EXP(-(E-1)/15))*(1-EXP(-(E-0.9)))  !7/11/96
      ENDIF
      ENDIF	
      IF(IFIX(ZP).EQ.2.AND.IFIX(AP).EQ.4) THEN
      CONST= CONST1 - 0.8/(1+EXP((250-E)/75))
      ENDIF	
      IF(IFIX(ZP).EQ.1.AND.IFIX(AP).EQ.1) THEN
      IF(AT.GT.45) THEN
      T1 = 40. + AT/3.
      ENDIF
      IF ( IFIX(AT).LT.4) THEN
      T1 = 55
      ENDIF
      CONST= 2.05 - 0.05/(1+EXP((250-E)/75))
      IF(IFIX(AT).LT.4) CONST =1.7
      IF ( IFIX(ZT).EQ. 12) THEN
      T1 = 40.
      CONST = 2.05 -3.0/(1.+TEXP((E-20)/10.))
      ENDIF       
      IF ( IFIX(ZT).EQ. 14) THEN
      T1 = 40.
      CONST = 2.05 -1.75/(1.+TEXP((E-20)/10.))
      ENDIF       
      IF ( IFIX(ZT).EQ. 18) THEN
      T1 = 40.
      CONST = 2.05 -2.0/(1.+TEXP((E-20)/10.))
      ENDIF       
      IF ( IFIX(ZT).EQ. 20) THEN
      T1 = 40.
      CONST = 2.05 -1.0/(1.+TEXP((E-40)/10.))
      ENDIF       
      ENDIF
      IF(IFIX(ZP).EQ.0.AND.IFIX(AP).EQ.1) THEN
	CONST = 2*(0.134457/DENSITY)   
        IF(AT.GT.140.AND.AT.LT.200)CONST = CONST -1.5*(AT-2*ZT)/AT   
        IF(AT.LT.60)  CONST = CONST -1.5*(AT-2*ZT)/AT   
	IF (AT.LE.40) CONST = CONST+0.25/(1+TEXP(-(170-E)/100.)) 
	IF(ZT.GT.82) CONST = CONST - ZT/(AT-ZT)
        IF(ZT.GE.82) CONST = const -2.0/(1.+TEXP((E-20)/20.))
        IF(ZT.LE.20.AND.ZT.GE.10)CONST=const -1.0/(1.+TEXP((E-20)/10.))
      ENDIF	
C	IF(IE.EQ.1)  PRINT*,'CONST =',CONST
      CE=CONST*(1.-EXP(-E/T1))-0.292*EXP(-E/792)*COS(0.229   
     1*E**0.453)
      TERM1 =(AT*AP)**(1./3.)/(AT**(1./3.)+AP**(1./3.))
      DELTA= 1.615*TERM1- 0.873*CE
      DELTA= DELTA+0.140*TERM1/ECM**(1./3.) 
      DELTA= DELTA+0.794*(AT-2*ZT)*ZP/(AT*AP)
      DELTA= -DELTA
      BETA = 1.
      TWXSEC= 10*PI*1.26*1.26*BETA*(0.873*AP**(1./3.)+0.873*AT**(1./3.)
     C -DELTA)**2
      XABS = TWXSEC*(1.-BIGB/ECM)*XM
      IF(XABS.LT.0) XABS =0.
      ZP = XQ1
      AP = XQ2
      ZT = XQ3
      AT = XQ4
      RETURN
      END
C 
C*******************fUNCTION RADIUS*****************
C
      FUNCTION RADIUS (A)
      DIMENSION NA(23),RMS(23)
      dATA NA/1,2,3,4,6,7,9,10,11,12,13,14,15,16,17,18,19,20,22,
     *23,24,25,26/
      DATA RMS/0.85,2.095,1.976,1.671,2.57,2.41,2.519,2.45,2.42,
     *2.471,2.440,2.58,2.611,2.730,2.662,2.727,2.900,3.040,2.969,2.94,
     *3.075,3.11,3.06/

      FACT = SQRT (5./3.)
      IA = A + 0.4
      RADIUS = FACT * ( 0.84* A**(1./3.) + 0.55 )

      DO 1 I =1,23
      IF ( IA .EQ. NA(I)) GO TO 2
      GO TO 1
  2   RADIUS = FACT*RMS(I)      
  1   CONTINUE

      RETURN
      END


C**************************************************************
C
      FUNCTION   TEXP(X)
C
C   PURPOSE
C   TO ELIMINATE OVER/UNDER FLOW OF CPU IF EXP IS USED
C
C   RESULT = TEXP(X)

      IF(X .LT.-80.)   X=-80.
      IF(X .GT. 80.)   X=80.
      TEXP =EXP(X)
      END
