************************************************************************
*                                                                      *
      SUBROUTINE PNEM2(PNRG,ATARG,ANGLE,ESECND,XSECT,DXSECT,
     &  SIGT,SIGNE,SIGS,DSIGS,ESCAT,ETARG,itip)
*                                                                      *
*-----------------------------------------------------------------------
*                                                                      *
*     PRELIMINARY VERSION, NOV.1, 1985.                                *
*     MAR. 10 1986, COVARIANCE INFORMATION ADDED.                      *
*     JUL.  1 1986, SIGT,SIGNE,SIGS,DSIGS,ESCAT,ETARG ADDED.           *
*     SEP.  1 1987, FIT OF HIGH ENERGY DIFF-ELASTIC TO EXP. DATA       *
*                                                                      *
*     FOR FURTHER INFORMATION CONTACT                                  *
*     S. PEARLSTEIN                                                    *
*     NATIONAL NUCLEAR DATA CENTER                                     *
*     BUILDING 197D                                                    *
*     BROOKHAVEN NATIONAL LABORATORY                                   *
*     UPTON, N.Y. 11973                                                *
*     (516) 282-2901, (FTS) 666-2901                                   *
*                                                                      *
*     CALCULATES CROSS-SECTION FOR EMISSION OF NEUTRONS FROM           *
*     TARGETS BOMBARDED BY HIGH ENERGY PROTONS, I.E. (P,XN) REACTION.  *
*     NOTE THAT ANY MULTIPLICATION FACTORS SUCH AS 2 FROM THE          *
*     (P,2N) REACTION ARE INCLUDED.                                    *
*     INPUT ARGUMENTS:                                                 *
*         PNRG=INCIDENT PROTON ENERGY (MEV), 0.005 < PNRG < 1000 MEV   *
*        ATARG=TARGET MASS (AMU), 5 < ATARG < 266, E.G. AMU FOR AL =27.*
*        ANGLE=NEUTRON EMISSION ANGLE (DEG)                            *
*             =-2., ANGULAR INTEGRATED XS (MICROB/MEV) RETURNED AS XSEC*
*       ESECND=NEUTRON EMISSION ENERGY (MEV), .LE. PNRG                *
*             =-2., ENERGY INTEGRATED XS (MICROB/SR) RETURNED AS XSECT *
*     RETURNED ARGUMENTS (SEE EXAMPLES FOR EXCEPTIONS):                *
*        XSECT=NEUTRON EMISSION CROSS-SECTION (MICROBARNS/SR-MEV)      *
*             IF ANGLE =-2., RETURNS ANGLE INTEGRATED XS (MICROB/MEV). *
*             IF ESECND=-2., RETURNS ENERGY INTEGRATED XS (MICROB/SR). *
*             IF ANGLE=ESECND=-2., RETURNS ENERGY-ANGLE INTEGRATED XS  *
*              (MICROB) YIELD RETURNED AS ESECND                       *
*       DXSECT=CROSS-SECTION UNCERTAINTY (MICROBARNS/SR-MEV)           *
*             =NON ZERO AS INPUT, RETURNS ENERGY-ANGLE INTEGRATED UNC. *
*              (MICROB)                                                *
*         SIGT=TOTAL CROSS-SECTION (B)                                 *
*        SIGNE=NONELASTIC CROSS-SECTION (B)                            *
*         SIGS=ELASTIC SCATTERING CROSS-SECTION (B)                    *
*        DSIGS=DIFFERENTIAL ELASTIC CROSS-SECTION (B/SR)               *
*        ESCAT=LAB KINETIC ENERGY OF SCATTERED NUCLEON (MEV)           *
*        ETARG=LAB KINETIC ENERGY OF SCATTERED TARGET (MEV)            *
*                                                                      *
*     PRIMARY REFERENCE - PEARLSTEIN, NUCL. SCI. ENG. 95,116-127(1987) *
*     PARAMETERS OBTAINED BY FITTING DATA AT 590 MEV REPORTED IN       *
*     D.FILGES ETAL., JUL-1960 OR KFK-3779, NOV. 1984                  *
*     FOR MASSES 12 THROUGH 238.  PARAMETERS ARE EXTRAPOLATED HERE     *
*     TO 6 AND 265, AND APPROXIMATED TO OTHER ENERGIES ON BASIS THAT   *
*     EMISSION AT 100 MEV IS VERY SMALL AND INCREASES AS THE LOG OF    *
*     THE INCIDENT PROTON ENERGY.  YIELDS AT LOWER ENERGIES ARE        *
*     EXTRAPOLATED USING THE CODE ALICE 85 BY M.BLANN.                 *
*     NO NEUTRONS ARE EMITTED ABOVE THE INCIDENT PROTON ENERGY.        *
*                                                                      *
*     SIGT, SIGS, DSIGS ARE NUCLEAR CROSS-SECTIONS ONLY.               *
*     COULOMB SCATTERING HAS NOT BEEN INCLUDED.  THEREFORE, ABOVE THE  *
*     COULOMB REACTION BARRIER, CROSS-SECTIONS ARE ALSO APPLICABLE TO  *
*     INCIDENT NEUTRONS.                                               *
*                                                                      *
*     XSECT= SUM (J=1,4) OF A(J)*E*EXP(-E/T(J)), WHERE                 *
*     A IS AN AMPLITUDE AND T IS A NUCLEAR TEMPERATURE PARAMETER.      *
*     EACH PARAMETER HAS AN ANGULAR DEPENDENCE,                        *
*     E.G. A=A(J)*(1.+A(J+1)*P1+A(J+2)*P2), WHERE                      *
*     P1 AND P2 ARE 1ST AND 2ND ORDER LEGENDRE POLYNOMIALS.            *
*                                                                      *
*     EXAMPLE INPUT: THE STATEMENT                                     *
*     CALL PNEM2(500.,90.,30.,1.,XSECT,DXSECT,6*DUMMY)                 *
*     WILL RETURN THE NEUTRON EMISSION CROSS-SECTION IN MICROB/SR-MEV  *
*     FOR A SECONDARY NEUTRON ENERGY AT 1 MEV                          *
*     AT 30 DEG FOR A 500 MEV INCIDENT PROTON ON A=90 (ZIRCONIUM).     *
*                                                                      *
*     IF ANGLE=ESECND=-2. AS INPUT,                                    *
*     THE ANGULAR, ENERGY INTEGRATED CROSS-SECTION (MICROB)            *
*     IS RETURNED.  IF DXSECT IS INPUT AS NON-ZERO, THE                *
*     UNCERTAINTY (MICROBARNS) IS RETURNED.  THE STATEMENT             *
*     CALL PNEM2(590.,27.,-2.,-2.,0.,0.,6*DUMMY)                       *
*     RETURNS THE ANGULAR, ENERGY INTEGRATED CROSS-SECTION FOR         *
*     NEUTRON PRODUCTION FROM ALUMINUM AT 590 MEV PROTON ENERGY.       *
*     THE YIELD (N'S/REACTING P'S) IS RETURNED AS ESECND.              *
*     CALL PNEM2(590.,27.,-2.,1.,0.,0.,6*DUMMY) RETURNS THE            *
*     ANGULAR INTEGRATED DIFFERENTIAL CROSS-SECTION (MICROB/MEV)       *
*     FOR PRODUCING 1 MEV NEUTRONS.                                    *
*      CALL PNEM2(590.,27.,30.,-2.,0.,0.,6*DUMMY)                      *
*     RETURNS THE ENERGY INTEGRATED DIFFERENTIAL CROSS-SECTION         *
*     (MICROB/SR) FOR PRODUCING NEUTRONS AT 30 DEGREES.                *
*                                                                      *
*     TO GET SIGT,SIGNE,SIGS; INPUT SIGT MUST BE .GE. 0.               *
*     TO GET DSIGS,ESCAT,ETARG; INPUT ANGLE MUST BE .GE. 0.            *
*                                                                      *
*      IF INCP=10, NEUTRON ARE INCIDENT; =10010, PROTONS               *
*      =10020, DEUTERONS (ONLY DIFF-ELASTIC VALID)                     *
*     DEFAULT INCIDENT PARTICLE IS A PROTON                            *
*                                                                      *
************************************************************************
*
      COMMON /INCP/   INCP
      COMMON /NSWCH/  NSWCH
*
      DIMENSION       P(10,8,3),PAR(8),AMAS(10),TEMP(8,3)
      DIMENSION       DP(10,8,3),CE(10,300),TEMP1(8,3),COR(300),S(8,3)
*
      DOUBLEPRECISION DANGLE
      NSWCH=0
*
*     ATOMIC MASS ARRAY
      DATA            AMAS/6.,12.,27.,56.,93.,115.,181.,207.,238.,265./
*
*----------------------------------------------------------------------*
*                                                                      *
*     FOLLOWING ARE 4-GROUP AMPLITUDE AND TEMPERATURE PARAMETERS FOR   *
*     MASSES 12,27,56,93,115,181,207,238,  RESPECTIVELY, IN THE ORDER  *
*     AVERAGE AMPLITUDE, LEGENDRE COEFFICIENTS (2),                    *
*     AVERAGE TEMPERATURE, LEGENDRE COEFFICIENTS (2).                  *
*                                                                      *
*     P(I,J,K) ARE 8 GROUPS OF 3 PARAMETERS EACH FOR EACH OF 8 MASSES. *
*     I INDEXES THE TARGET MASS IN THE AMAS ARRAY.                     *
*     J=1,3,5,7 REFERS TO THE 4-GROUP CROSS-SECTION AMPLITUDES.        *
*      =2,4,6,8 REFERS TO THE 4-GROUP EMISSION TEMPERATURES.           *
*     K=1, REFERS TO THE CENTRAL TERM (IS DIMENSIONED).                *
*      =2,3 REFERS TO THE DIMENSIONLESS COEFFICIENTS OF LEGENDRE       *
*           POLYNOMIALS.                                               *
*     E.G. T(4) FOR CARBON AT 90 DEGREES IS                            *
*        85.9*(1.+0.000688*0.+0.618*0.5) (MEV)                         *
*     DP(I,J,K) ARE UNCERTAINTIES OF P(I,J,K)                          *
*     CE(I,J) ARE PARAMETER CORRELATIONS.                              *
*     I INDEXES THE TARGET MASS IN THE AMAS ARRAY,                     *
*     J IS THE SEQUENCE NO. OF ELEMENT IN 300 ELEMENT PACKED           *
*     LOWER TRIANGULAR 24 X 24 MATRIX.                                 *
*     COORDINATES OF K,L ELEMENT IS RELATED TO J BY                    *
*       J=K*(K-1)/2+L, OR TO GO THE OTHER WAY,                         *
*       K=1/2+1/2*SQRT(1+8*J), WITH FIXED POINT ROUNDING DOWN,         *
*       L=J-K*(K-1)/2.                                                 *
*                                                                      *
*     UNCERTAINTY IN RESULT, R, IS                                     *
*       DR**2=((SUM(K,L),L=1,K),K=1,24) OF                             *
*             FACT*(DR/DP(K))*(DR/DP(L))*CORR(K,L)*DP(K)*DP(L),        *
*             WHERE FACT=1. IF K.EQ.L, AND 2. IF K.NE.L.               *
*                                                                      *
*----------------------------------------------------------------------*
*
      DATA ((P(2,J,K),K=1,3),J=1,8)/
     &   1.12E+4, 1.34E+0, 7.07E-1, 9.87E-1,-2.87E-1, 2.66E-1,
     &   4.52E+2, 9.30E-1,-8.88E-2, 3.98E+0,-3.45E-1, 2.80E-1,
     &   1.19E+1, 1.31E+0, 7.34E-1, 2.53E+1,-1.29E-1,-7.64E-3,
     &   2.03E+0, 1.14E+0, 1.01E-1, 8.59E+1, 6.88E-4, 6.18E-1/
*
      DATA ((DP(2,J,K),K=1,3),J=1,8)/
     &   7.81E+1, 3.77E-2, 9.97E-2, 8.68E-3, 7.99E-2, 1.78E-2,
     &   6.43E+1, 5.48E-1, 5.12E+0, 1.51E-1, 9.00E-1, 4.90E-1,
     &   1.42E-1, 3.56E-1, 3.30E-1, 2.02E-2, 1.44E+0, 3.50E+1,
     &   3.06E-1, 2.70E-1, 8.51E+0, 3.89E+0, 4.51E+1, 2.88E-1/
*
      DATA (CE(2,J),J=1,190)/
     &   1.00, 0.26, 1.00, 0.02, 0.95, 1.00,-0.67, 0.35, 0.49, 1.00,
     &   0.62, 0.46, 0.22,-0.23, 1.00, 0.27,-0.65,-0.80,-0.68, 0.18,
     &   1.00, 0.41, 0.10,-0.01,-0.56, 0.51, 0.25, 1.00, 0.18, 0.45,
     &   0.41, 0.17, 0.46,-0.47, 0.40, 1.00,-0.14,-0.45,-0.44,-0.21,
     &  -0.33, 0.57,-0.30,-0.98, 1.00,-0.19, 0.01, 0.03, 0.46,-0.02,
     &  -0.09,-0.68,-0.07, 0.12, 1.00, 0.20, 0.20, 0.11,-0.03, 0.61,
     &   0.07, 0.52, 0.61,-0.43, 0.16, 1.00, 0.02,-0.24,-0.30,-0.19,
     &   0.14, 0.56, 0.04,-0.55, 0.71, 0.29, 0.26, 1.00, 0.12, 0.08,
     &   0.05,-0.15, 0.20,-0.01, 0.48, 0.35,-0.32,-0.47, 0.40,-0.16,
     &   1.00, 0.08, 0.14, 0.12, 0.04, 0.21,-0.15, 0.25, 0.52,-0.49,
     &  -0.04, 0.49,-0.33, 0.61, 1.00, 0.04, 0.13, 0.13, 0.07, 0.11,
     &  -0.21, 0.13, 0.48,-0.50,-0.05, 0.26,-0.51, 0.41, 0.92, 1.00,
     &  -0.06, 0.02, 0.04, 0.15,-0.06,-0.11,-0.28, 0.02,-0.05, 0.38,
     &  -0.09,-0.13,-0.56, 0.08, 0.25, 1.00, 0.09, 0.08, 0.05,-0.04,
     &   0.24, 0.00, 0.32, 0.35,-0.28,-0.08, 0.56, 0.01, 0.74, 0.76,
     &   0.50,-0.32, 1.00,-0.01, 0.08, 0.09, 0.10,-0.01,-0.19,-0.06,
     &   0.26,-0.30, 0.05,-0.01,-0.45, 0.04, 0.54, 0.72, 0.69, 0.08,
     &   1.00, 0.03,-0.02,-0.03,-0.08, 0.04, 0.08, 0.14,-0.04, 0.06,
     &  -0.16, 0.08, 0.15, 0.24,-0.05,-0.15,-0.81, 0.26,-0.66, 1.00/
*
      DATA (CE(2,J),J=191,300)/
     &  -0.01, 0.04, 0.04, 0.07, 0.01,-0.09,-0.05, 0.13,-0.14, 0.10,
     &   0.04,-0.18,-0.00, 0.26, 0.32, 0.65, 0.10, 0.76,-0.77, 1.00,
     &  -0.01, 0.04, 0.04, 0.07,-0.00,-0.09,-0.06, 0.12,-0.14, 0.09,
     &   0.00,-0.21,-0.02, 0.24, 0.31, 0.67, 0.04, 0.78,-0.80, 0.99,
     &   1.00,-0.01, 0.02, 0.01, 0.06, 0.04,-0.01,-0.07, 0.04,-0.02,
     &   0.26, 0.14, 0.08,-0.18, 0.10, 0.04, 0.63, 0.07, 0.30,-0.72,
     &   0.55, 0.52, 1.00,-0.03,-0.02, 0.00,-0.00,-0.12,-0.05,-0.07,
     &  -0.08, 0.03,-0.17,-0.32,-0.20,-0.10,-0.23,-0.04,-0.03,-0.54,
     &   0.13,-0.13,-0.16,-0.07,-0.48, 1.00, 0.02,-0.02,-0.04,-0.05,
     &   0.06, 0.10, 0.08,-0.07, 0.11, 0.03, 0.15, 0.28, 0.02,-0.09,
     &  -0.24,-0.50, 0.21,-0.72, 0.71,-0.80,-0.85,-0.15,-0.41, 1.00/
*
      DATA ((P(3,J,K),K=1,3),J=1,8)/
     &   3.03E+4, 1.01E+0, 3.85E-1, 9.73E-1,-1.90E-1, 1.42E-1,
     &   2.77E+3, 8.94E-1, 6.61E-2, 3.26E+0,-2.05E-1, 1.55E-1,
     &   4.58E+1, 9.54E-1, 2.26E-1, 2.26E+1,-1.02E-1, 9.64E-2,
     &   8.04E+0, 1.08E+0, 8.43E-2, 7.08E+1, 2.52E-1, 3.10E-1/
*
      DATA ((DP(3,J,K),K=1,3),J=1,8)/
     &   6.76E+2, 7.81E-3, 1.88E-2, 6.35E-3, 2.25E-2, 1.90E-1,
     &   1.02E+2, 1.79E-1, 6.81E+0, 1.33E-2, 9.39E-2, 3.45E-1,
     &   2.80E-1, 1.28E-1, 5.49E-1, 1.39E-3, 1.58E-1, 3.75E-1,
     &   2.72E-2, 2.31E-2, 4.69E-2, 1.04E-1, 3.46E-2, 2.10E-2/
*
      DATA (CE(3,J),J=1,190)/
     &   1.00, 0.20, 1.00,-0.09, 0.91, 1.00,-0.72, 0.24, 0.40, 1.00,
     &   0.50, 0.57, 0.27,-0.16, 1.00, 0.30,-0.57,-0.77,-0.59, 0.08,
     &   1.00, 0.37, 0.08,-0.03,-0.66, 0.44, 0.29, 1.00, 0.09, 0.42,
     &   0.39, 0.21, 0.54,-0.52, 0.19, 1.00, 0.01, 0.40, 0.43, 0.30,
     &   0.30,-0.70,-0.01, 0.93, 1.00,-0.23, 0.04, 0.08, 0.62,-0.07,
     &  -0.26,-0.84, 0.15, 0.21, 1.00, 0.18, 0.23, 0.12,-0.06, 0.69,
     &   0.05, 0.49, 0.67, 0.37,-0.04, 1.00, 0.08,-0.23,-0.31,-0.31,
     &   0.06, 0.69, 0.25,-0.62,-0.85,-0.25, 0.10, 1.00, 0.11, 0.04,
     &   0.01,-0.24, 0.19, 0.07, 0.49, 0.18, 0.08,-0.52, 0.36, 0.07,
     &   1.00, 0.04, 0.12, 0.11, 0.05, 0.22,-0.20, 0.15, 0.51, 0.47,
     &   0.04, 0.45,-0.41, 0.36, 1.00, 0.02, 0.12, 0.12, 0.09, 0.14,
     &  -0.26, 0.03, 0.48, 0.50, 0.11, 0.27,-0.54, 0.14, 0.93, 1.00,
     &  -0.07, 0.00, 0.02, 0.19,-0.07,-0.09,-0.33,-0.00, 0.05, 0.44,
     &  -0.13,-0.13,-0.80,-0.01, 0.14, 1.00, 0.06, 0.08, 0.05,-0.04,
     &   0.23,-0.04, 0.25, 0.34, 0.24,-0.10, 0.49,-0.08, 0.60, 0.76,
     &   0.53,-0.32, 1.00, 0.00,-0.07,-0.09,-0.09,-0.03, 0.22, 0.04,
     &  -0.31,-0.37,-0.10,-0.07, 0.48, 0.03,-0.68,-0.84,-0.29,-0.27,
     &   1.00, 0.02, 0.00,-0.00,-0.04, 0.04, 0.02, 0.09, 0.02, 0.00,
     &  -0.11, 0.08, 0.04, 0.25, 0.06,-0.00,-0.55, 0.29, 0.18, 1.00/
*
      DATA (CE(3,J),J=191,300)/
     &   0.02, 0.04, 0.03, 0.01, 0.07,-0.05, 0.06, 0.16, 0.14, 0.00,
     &   0.16,-0.12, 0.15, 0.37, 0.34, 0.10, 0.49,-0.50,-0.08, 1.00,
     &   0.01, 0.03, 0.03, 0.01, 0.04,-0.07, 0.04, 0.14, 0.15,-0.02,
     &   0.08,-0.18, 0.13, 0.33, 0.36, 0.08, 0.32,-0.61,-0.17, 0.94,
     &   1.00,-0.00,-0.00,-0.01, 0.02, 0.03, 0.03,-0.02, 0.00,-0.03,
     &   0.08, 0.08, 0.08,-0.09, 0.01,-0.06, 0.40, 0.07, 0.11,-0.71,
     &   0.13,-0.02, 1.00,-0.02,-0.02,-0.01,-0.00,-0.10,-0.02,-0.06,
     &  -0.10,-0.04,-0.04,-0.23,-0.07,-0.12,-0.24,-0.09,-0.05,-0.57,
     &  -0.05,-0.21,-0.57,-0.27,-0.33, 1.00,-0.01,-0.02,-0.02, 0.02,
     &   0.01, 0.07,-0.04,-0.07,-0.11, 0.09, 0.04, 0.18,-0.15,-0.16,
     &  -0.25, 0.11,-0.02, 0.55, 0.10,-0.56,-0.79, 0.39,-0.25, 1.00/
*
      DATA ((P(4,J,K),K=1,3),J=1,8)/
     &   5.11E+4, 7.74E-1, 3.60E-1, 1.02E+0,-3.71E-1, 2.91E-1,
     &   1.30E+4, 5.75E-1,-5.88E-1, 2.99E+0,-3.06E-1, 3.69E-1,
     &   1.66E+2, 6.55E-1,-4.01E-1, 1.85E+1,-1.78E-1, 3.86E-1,
     &   2.08E+1, 9.73E-1,-2.29E-1, 7.33E+1, 6.27E-2, 3.90E-1/
*
      DATA ((DP(4,J,K),K=1,3),J=1,8)/
     &   5.95E+3, 1.69E-1, 9.36E-1, 1.32E-1, 1.61E-1, 7.37E-1,
     &   2.34E+3, 3.86E-1, 3.49E-1, 8.93E-2, 4.39E-1, 1.62E-1,
     &   1.24E+1, 1.15E-1, 3.35E-1, 2.65E-1, 5.94E-1, 2.72E-1,
     &   8.19E-1, 5.03E-2, 5.04E-1, 5.79E-1, 1.28E+0, 1.61E-1/
*
      DATA (CE(4,J),J=1,190)/
     &   1.00,-0.03, 1.00,-0.48, 0.86, 1.00,-0.65, 0.27, 0.52, 1.00,
     &   0.55, 0.44, 0.04,-0.45, 1.00, 0.44,-0.51,-0.70,-0.84, 0.28,
     &   1.00, 0.16,-0.01,-0.09,-0.75, 0.47, 0.64, 1.00, 0.05, 0.37,
     &   0.30, 0.39, 0.35,-0.61,-0.34, 1.00, 0.02,-0.34,-0.33,-0.50,
     &  -0.11, 0.75, 0.50,-0.94, 1.00, 0.06,-0.09,-0.13, 0.38,-0.06,
     &  -0.12,-0.65, 0.17,-0.09, 1.00, 0.17, 0.15, 0.01,-0.16, 0.67,
     &   0.16, 0.34, 0.46,-0.15, 0.21, 1.00, 0.09,-0.18,-0.23,-0.50,
     &   0.25, 0.72, 0.62,-0.62, 0.83, 0.03, 0.36, 1.00,-0.00, 0.03,
     &   0.02,-0.27, 0.20, 0.22, 0.48,-0.11, 0.18,-0.47, 0.24, 0.33,
     &   1.00, 0.03, 0.10, 0.07, 0.16, 0.13,-0.26,-0.17, 0.51,-0.50,
     &   0.07, 0.28,-0.44,-0.16, 1.00,-0.03,-0.08,-0.06,-0.20,-0.06,
     &   0.30, 0.25,-0.50, 0.52,-0.09,-0.15, 0.53, 0.34,-0.97, 1.00,
     &  -0.00,-0.03,-0.02, 0.20,-0.15,-0.13,-0.35, 0.03,-0.07, 0.42,
     &  -0.16,-0.15,-0.89, 0.01,-0.15, 1.00, 0.02, 0.08, 0.05,-0.02,
     &   0.22,-0.05, 0.12, 0.31,-0.22,-0.09, 0.42,-0.05, 0.42, 0.69,
     &  -0.52,-0.50, 1.00,-0.02,-0.05,-0.04,-0.18, 0.02, 0.26, 0.27,
     &  -0.36, 0.41,-0.10, 0.01, 0.49, 0.51,-0.79, 0.89,-0.33,-0.30,
     &   1.00, 0.00, 0.01, 0.01,-0.07, 0.07, 0.05, 0.13, 0.01, 0.02,
     &  -0.14, 0.10, 0.07, 0.39, 0.02, 0.05,-0.58, 0.38, 0.19, 1.00/
*
      DATA (CE(4,J),J=191,300)/
     &   0.01, 0.02, 0.02, 0.05, 0.03,-0.07,-0.06, 0.14,-0.14, 0.03,
     &   0.07,-0.13,-0.10, 0.35,-0.35, 0.04, 0.39,-0.50,-0.03, 1.00,
     &  -0.01,-0.02,-0.02,-0.05,-0.02, 0.08, 0.06,-0.14, 0.14,-0.02,
     &  -0.05, 0.14, 0.11,-0.35, 0.36,-0.03,-0.36, 0.52, 0.05,-1.00,
     &   1.00,-0.01,-0.00,-0.00, 0.03, 0.03, 0.01,-0.03, 0.01, 0.03,
     &   0.18, 0.13, 0.11,-0.12, 0.01, 0.05, 0.34, 0.08, 0.13,-0.36,
     &  -0.02, 0.09, 1.00, 0.00,-0.01,-0.01,-0.01,-0.07,-0.02,-0.01,
     &  -0.05,-0.01,-0.13,-0.20,-0.11,-0.02,-0.10, 0.01,-0.09,-0.36,
     &  -0.10,-0.13,-0.24, 0.16,-0.81, 1.00,-0.01,-0.00,-0.00,-0.01,
     &   0.05, 0.05, 0.03,-0.03, 0.08, 0.13, 0.15, 0.17, 0.05,-0.09,
     &   0.17, 0.11, 0.11, 0.35, 0.05,-0.34, 0.41, 0.85,-0.80, 1.00/
*
      DATA ((P(5,J,K),K=1,3),J=1,8)/
     &   1.11E+5, 7.18E-1, 3.91E-1, 1.11E+0,-4.01E-1, 2.22E-1,
     &   3.73E+4, 4.77E-1,-7.44E-1, 2.69E+0,-2.73E-1, 3.69E-1,
     &   3.76E+2, 4.65E-1,-4.97E-1, 1.47E+1, 6.93E-3, 3.94E-1,
     &   3.74E+1, 7.06E-1,-2.94E-1, 6.05E+1, 4.14E-1, 2.43E-1/
*
      DATA ((DP(5,J,K),K=1,3),J=1,8)/
     &   1.10E+4, 1.50E-1, 1.02E+0, 2.75E-1, 2.30E-1, 5.15E+0,
     &   6.46E+4, 1.14E+0, 2.60E+0, 1.96E-1, 1.43E-1, 6.48E-1,
     &   3.59E+2, 4.69E-1, 2.19E+0, 1.80E+0, 1.75E+0, 5.27E-1,
     &   1.91E+0, 7.83E-2, 3.80E-2, 2.11E-1, 4.16E-2, 2.90E-2/
*
      DATA (CE(5,J),J=1,190)/
     &   1.00, 0.18, 1.00,-0.33, 0.82, 1.00,-0.05,-0.05,-0.03, 1.00,
     &   0.31, 0.55, 0.30,-0.44, 1.00,-0.17,-0.19,-0.13,-0.86, 0.34,
     &   1.00,-0.37, 0.19, 0.37,-0.84, 0.44, 0.78, 1.00, 0.42, 0.12,
     &  -0.10, 0.64, 0.16,-0.74,-0.67, 1.00,-0.43,-0.05, 0.17,-0.69,
     &   0.13, 0.87, 0.79,-0.92, 1.00, 0.26,-0.17,-0.28, 0.50, 0.05,
     &  -0.22,-0.58, 0.46,-0.25, 1.00,-0.00, 0.14, 0.14,-0.03, 0.64,
     &   0.18, 0.19, 0.32, 0.07, 0.52, 1.00,-0.35, 0.06, 0.24,-0.52,
     &   0.41, 0.75, 0.70,-0.57, 0.84, 0.09, 0.57, 1.00,-0.27, 0.14,
     &   0.28,-0.37, 0.23, 0.35, 0.54,-0.32, 0.40,-0.39, 0.19, 0.45,
     &   1.00, 0.20,-0.01,-0.11, 0.29, 0.09,-0.35,-0.33, 0.56,-0.50,
     &   0.26, 0.27,-0.34,-0.35, 1.00,-0.28, 0.06, 0.21,-0.30, 0.08,
     &   0.40, 0.44,-0.50, 0.56,-0.14, 0.08, 0.59, 0.66,-0.84, 1.00,
     &   0.15,-0.10,-0.18, 0.25,-0.18,-0.20,-0.36, 0.15,-0.20, 0.33,
     &  -0.12,-0.23,-0.85, 0.13,-0.36, 1.00,-0.01,-0.06,-0.06,-0.08,
     &  -0.22, 0.09,-0.00,-0.30, 0.17,-0.15,-0.45,-0.06,-0.26,-0.71,
     &   0.29, 0.37, 1.00,-0.24, 0.06, 0.20,-0.23, 0.10, 0.32, 0.37,
     &  -0.36, 0.45,-0.08, 0.17, 0.53, 0.69,-0.68, 0.92,-0.44, 0.13,
     &   1.00,-0.04, 0.02, 0.05,-0.04, 0.05, 0.04, 0.07,-0.02, 0.05,
     &  -0.03, 0.09, 0.09, 0.27,-0.02, 0.14,-0.46,-0.24, 0.26, 1.00/
*
      DATA (CE(5,J),J=191,300)/
     &   0.02, 0.02, 0.01, 0.02, 0.07,-0.04,-0.00, 0.12,-0.09, 0.01,
     &   0.12,-0.03, 0.05, 0.34,-0.22,-0.14,-0.51,-0.29,-0.03, 1.00,
     &  -0.09, 0.02, 0.07,-0.09, 0.02, 0.12, 0.14,-0.15, 0.17,-0.06,
     &   0.02, 0.18, 0.30,-0.33, 0.40,-0.22, 0.20, 0.56, 0.35,-0.85,
     &   1.00,-0.05, 0.03, 0.06,-0.08, 0.04, 0.07, 0.12,-0.08, 0.09,
     &  -0.10, 0.01, 0.08, 0.18,-0.09, 0.13,-0.00, 0.06, 0.12,-0.73,
     &  -0.09, 0.04, 1.00, 0.08,-0.07,-0.11, 0.11,-0.15,-0.08,-0.18,
     &  -0.00,-0.06, 0.12,-0.19,-0.14,-0.50,-0.15,-0.10, 0.62, 0.60,
     &  -0.15,-0.44,-0.73, 0.31, 0.27, 1.00,-0.12, 0.05, 0.11,-0.14,
     &   0.08, 0.15, 0.21,-0.15, 0.19,-0.12, 0.08, 0.22, 0.48,-0.26,
     &   0.42,-0.45,-0.01, 0.58, 0.43,-0.61, 0.89, 0.03, 0.11, 1.00/
*
      DATA ((P(6,J,K),K=1,3),J=1,8)/
     &   1.98E+5, 4.00E-1, 9.77E-4, 1.28E+0,-4.06E-1,-3.00E-2,
     &   2.74E+4, 1.36E+0, 4.28E-1, 3.42E+0,-4.43E-1, 1.88E-1,
     &   3.34E+2, 9.02E-1, 1.16E-2, 1.62E+1,-2.37E-1, 3.90E-1,
     &   5.43E+1, 7.47E-1,-5.05E-1, 6.04E+1, 2.00E-1, 4.22E-1/
*
      DATA ((DP(6,J,K),K=1,3),J=1,8)/
     &   7.04E+3, 1.15E-2, 8.94E+0, 3.13E-2, 2.97E-2, 2.87E+0,
     &   1.80E+4, 1.36E+0, 7.67E+0, 1.12E-1, 6.57E-1, 4.90E+0,
     &   4.23E+2, 1.70E+0, 3.47E+1, 5.19E-1, 8.12E-1, 2.01E+0,
     &   1.83E+0, 1.31E-2, 4.37E-2, 5.76E-2, 1.35E-2, 4.68E-3/
*
      DATA (CE(6,J),J=1,190)/
     &   1.00, 0.73, 1.00, 0.49, 0.90, 1.00,-0.54,-0.27,-0.12, 1.00,
     &   0.67, 0.78, 0.59,-0.54, 1.00, 0.17, 0.45, 0.60, 0.45, 0.21,
     &   1.00, 0.19, 0.19, 0.14,-0.83, 0.54,-0.40, 1.00, 0.10, 0.20,
     &   0.21, 0.56, 0.16, 0.80,-0.56, 1.00, 0.09, 0.16, 0.19, 0.58,
     &   0.07, 0.83,-0.61, 0.98, 1.00,-0.03,-0.00,-0.03, 0.65,-0.08,
     &   0.38,-0.73, 0.72, 0.66, 1.00, 0.05, 0.12, 0.05,-0.17, 0.43,
     &  -0.25, 0.36,-0.05,-0.22, 0.26, 1.00,-0.04,-0.01,-0.06,-0.46,
     &   0.20,-0.67, 0.61,-0.68,-0.79,-0.30, 0.74, 1.00,-0.02, 0.06,
     &   0.08,-0.37, 0.19,-0.26, 0.56,-0.43,-0.46,-0.58, 0.26, 0.54,
     &   1.00, 0.07, 0.03, 0.00, 0.29, 0.02, 0.39,-0.37, 0.59, 0.59,
     &   0.54,-0.11,-0.56,-0.72, 1.00, 0.06, 0.01,-0.01, 0.32,-0.03,
     &   0.39,-0.43, 0.57, 0.60, 0.52,-0.23,-0.63,-0.82, 0.98, 1.00,
     &   0.02,-0.04,-0.06, 0.28,-0.13, 0.20,-0.42, 0.35, 0.36, 0.49,
     &  -0.17,-0.41,-0.94, 0.72, 0.79, 1.00, 0.03, 0.08, 0.07,-0.09,
     &   0.24, 0.03, 0.23, 0.09, 0.02, 0.03, 0.43, 0.23, 0.44, 0.16,
     &  -0.04,-0.35, 1.00,-0.06, 0.00, 0.02,-0.26, 0.06,-0.31, 0.38,
     &  -0.45,-0.48,-0.41, 0.28, 0.58, 0.83,-0.89,-0.94,-0.85, 0.20,
     &   1.00,-0.01, 0.02, 0.03,-0.11, 0.07,-0.07, 0.18,-0.13,-0.14,
     &  -0.19, 0.10, 0.19, 0.48,-0.33,-0.38,-0.63, 0.33, 0.52, 1.00/
*
      DATA (CE(6,J),J=191,300)/
     &   0.03, 0.01, 0.00, 0.07, 0.03, 0.11,-0.09, 0.18, 0.17, 0.16,
     &  -0.01,-0.16,-0.25, 0.41, 0.38, 0.34, 0.22,-0.48,-0.35, 1.00,
     &  -0.03,-0.01,-0.00,-0.08,-0.02,-0.12, 0.10,-0.18,-0.19,-0.15,
     &   0.05, 0.19, 0.27,-0.41,-0.41,-0.35,-0.14, 0.52, 0.39,-0.99,
     &   1.00,-0.01,-0.01,-0.02, 0.03,-0.01,-0.03,-0.04, 0.00,-0.02,
     &   0.13, 0.13, 0.08,-0.17, 0.08, 0.05, 0.32, 0.06,-0.05,-0.51,
     &   0.02, 0.08, 1.00, 0.00,-0.01,-0.01, 0.01,-0.06, 0.02,-0.05,
     &  -0.01, 0.02,-0.09,-0.22,-0.14,-0.05,-0.08, 0.01,-0.04,-0.47,
     &  -0.07,-0.11,-0.38, 0.24,-0.51, 1.00,-0.02,-0.01,-0.00,-0.05,
     &   0.02,-0.11, 0.09,-0.12,-0.14,-0.02, 0.19, 0.23, 0.18,-0.22,
     &  -0.27,-0.15, 0.19, 0.39, 0.24,-0.52, 0.64, 0.62,-0.47, 1.00/
*
      DATA ((P(7,J,K),K=1,3),J=1,8)/
     &   3.51E+5, 3.38E-3,-2.17E-1, 1.23E+0,-1.57E-1, 2.96E-1,
     &   8.43E+4, 6.04E-1,-6.04E-1, 2.92E+0,-3.49E-1, 3.76E-1,
     &   6.32E+2, 6.48E-1,-2.27E-1, 1.56E+1,-9.70E-2, 4.67E-1,
     &   6.86E+1, 7.99E-1,-3.36E-1, 6.06E+1, 2.55E-1, 4.02E-1/
*
      DATA ((DP(7,J,K),K=1,3),J=1,8)/
     &   2.33E+3, 5.67E+0, 3.84E-2, 5.91E-2, 1.88E-1, 1.42E-1,
     &   5.13E+4, 1.69E-1, 1.47E-1, 1.61E-1, 3.27E-1, 1.57E-1,
     &   3.24E+2, 4.20E-1, 2.85E+0, 1.09E+0, 3.46E-1, 1.41E-1,
     &   1.42E+0, 1.19E-2, 7.13E-3, 4.57E-2, 1.10E-2, 3.65E-3/
*
      DATA (CE(7,J),J=1,190)/
     &   1.00, 0.25, 1.00, 0.63,-0.35, 1.00,-0.30, 0.04,-0.29, 1.00,
     &  -0.09,-0.04, 0.09,-0.46, 1.00, 0.32, 0.15, 0.26,-0.40,-0.49,
     &   1.00,-0.19,-0.17, 0.03,-0.81, 0.38, 0.41, 1.00,-0.15,-0.39,
     &   0.20,-0.04, 0.80,-0.78,-0.04, 1.00, 0.13, 0.39,-0.18,-0.05,
     &  -0.71, 0.84, 0.15,-0.98, 1.00, 0.22, 0.25, 0.07, 0.43,-0.10,
     &  -0.03,-0.55,-0.00, 0.05, 1.00,-0.15,-0.24, 0.19,-0.37, 0.70,
     &  -0.11, 0.47, 0.56,-0.40, 0.25, 1.00,-0.00, 0.27,-0.11,-0.30,
     &  -0.19, 0.73, 0.49,-0.60, 0.73, 0.23, 0.31, 1.00,-0.14,-0.06,
     &  -0.06,-0.35, 0.12, 0.25, 0.53,-0.11, 0.18,-0.30, 0.29, 0.43,
     &   1.00,-0.03,-0.30, 0.22, 0.03, 0.33,-0.37,-0.10, 0.54,-0.54,
     &   0.06, 0.31,-0.44,-0.35, 1.00,-0.04, 0.24,-0.21,-0.12,-0.21,
     &   0.40, 0.25,-0.47, 0.52,-0.03,-0.05, 0.59, 0.63,-0.91, 1.00,
     &   0.10, 0.08, 0.01, 0.25,-0.13,-0.13,-0.36, 0.01,-0.06, 0.25,
     &  -0.22,-0.23,-0.87, 0.17,-0.40, 1.00,-0.12,-0.25, 0.12,-0.15,
     &   0.32,-0.12, 0.22, 0.34,-0.28, 0.01, 0.50, 0.03, 0.37, 0.63,
     &  -0.30,-0.44, 1.00,-0.05, 0.17,-0.16,-0.11,-0.12, 0.31, 0.23,
     &  -0.34, 0.39, 0.04, 0.08, 0.54, 0.68,-0.76, 0.92,-0.51,-0.11,
     &   1.00,-0.03,-0.03, 0.00,-0.04, 0.05, 0.02, 0.08, 0.02,-0.01,
     &  -0.01, 0.10, 0.07, 0.27,-0.00, 0.11,-0.47, 0.30, 0.23, 1.00/
*
      DATA (CE(7,J),J=191,300)/
     &  -0.02,-0.10, 0.06,-0.03, 0.11,-0.08, 0.03, 0.15,-0.14,-0.03,
     &   0.12,-0.10,-0.03, 0.36,-0.30,-0.03, 0.44,-0.37, 0.01, 1.00,
     &  -0.01, 0.08,-0.07,-0.01,-0.07, 0.11, 0.05,-0.15, 0.16, 0.01,
     &  -0.03, 0.17, 0.21,-0.37, 0.39,-0.15,-0.26, 0.52, 0.16,-0.95,
     &   1.00,-0.05,-0.00,-0.03,-0.10, 0.03, 0.09, 0.16,-0.05, 0.08,
     &  -0.05, 0.11, 0.18, 0.33,-0.15, 0.27,-0.14, 0.09, 0.32,-0.49,
     &  -0.20, 0.32, 1.00, 0.08, 0.09,-0.02, 0.14,-0.13,-0.04,-0.22,
     &  -0.07, 0.03, 0.06,-0.26,-0.15,-0.48,-0.10,-0.12, 0.52,-0.62,
     &  -0.22,-0.46,-0.57, 0.29,-0.08, 1.00,-0.05, 0.02,-0.05,-0.10,
     &   0.01, 0.13, 0.18,-0.09, 0.12,-0.03, 0.13, 0.25, 0.49,-0.27,
     &   0.43,-0.43, 0.12, 0.60, 0.28,-0.58, 0.78, 0.55,-0.19, 1.00/
*
      DATA ((P(8,J,K),K=1,3),J=1,8)/
     &   3.78E+5, 1.31E-1, 2.00E-2, 1.48E+0,-1.28E-1, 4.54E-2,
     &   4.22E+4, 8.51E-1,-1.01E-1, 3.37E+0,-2.54E-1, 1.69E-1,
     &   4.64E+2, 6.83E-1, 1.17E-1, 1.95E+1,-1.65E-3, 2.67E-1,
     &   4.66E+1, 9.90E-1,-6.57E-3, 6.64E+1, 2.46E-1, 2.68E-1/
*
      DATA ((DP(8,J,K),K=1,3),J=1,8)/
     &   2.29E+3, 1.82E-1, 1.04E-1, 2.42E-2, 2.97E-3, 1.22E+0,
     &   2.53E+4, 9.68E-1, 1.84E+1, 3.71E-1, 9.34E-1, 1.84E+0,
     &   1.04E+2, 1.67E-1, 2.20E+0, 1.05E+0, 3.75E+0, 2.64E-1,
     &   8.84E-1, 3.44E-2, 3.00E+0, 9.85E-2, 7.57E-2, 3.74E-2/
*
      DATA (CE(8,J),J=1,190)/
     &   1.00, 0.22, 1.00,-0.38, 0.42, 1.00,-0.25,-0.01, 0.10, 1.00,
     &   0.04, 0.31, 0.04,-0.41, 1.00, 0.08,-0.04,-0.28,-0.45,-0.37,
     &   1.00,-0.19,-0.06, 0.06,-0.86, 0.48, 0.36, 1.00, 0.00,-0.10,
     &  -0.13, 0.15, 0.68,-0.79,-0.07, 1.00,-0.05, 0.12, 0.12,-0.26,
     &  -0.53, 0.87, 0.24,-0.96, 1.00, 0.18, 0.12,-0.12, 0.72,-0.16,
     &  -0.27,-0.82, 0.24,-0.26, 1.00,-0.14,-0.02,-0.09,-0.26, 0.68,
     &  -0.04, 0.43, 0.49,-0.25, 0.09, 1.00,-0.14, 0.15, 0.12,-0.36,
     &  -0.11, 0.76, 0.45,-0.65, 0.82,-0.18, 0.32, 1.00,-0.16,-0.06,
     &   0.07,-0.47, 0.21, 0.22, 0.60,-0.10, 0.18,-0.61, 0.24, 0.32,
     &   1.00,-0.01,-0.16,-0.17, 0.10, 0.26,-0.32,-0.06, 0.51,-0.48,
     &   0.20, 0.34,-0.36,-0.13, 1.00, 0.08,-0.13,-0.18, 0.26, 0.10,
     &  -0.41,-0.30, 0.47,-0.53, 0.29, 0.00,-0.59,-0.51, 0.82, 1.00,
     &   0.13, 0.05,-0.05, 0.34,-0.15,-0.15,-0.45, 0.08,-0.13, 0.48,
     &  -0.15,-0.23,-0.92, 0.15, 0.45, 1.00,-0.09,-0.13,-0.09,-0.11,
     &   0.28,-0.11, 0.20, 0.31,-0.23,-0.04, 0.44,-0.02, 0.37, 0.76,
     &   0.34,-0.34, 1.00,-0.08, 0.10, 0.15,-0.22,-0.05, 0.33, 0.28,
     &  -0.36, 0.42,-0.24, 0.07, 0.52, 0.53,-0.69,-0.93,-0.52,-0.25,
     &   1.00,-0.05,-0.03, 0.01,-0.12, 0.08, 0.03, 0.16, 0.02, 0.01,
     &  -0.16, 0.10, 0.07, 0.41, 0.03,-0.14,-0.60, 0.35, 0.23, 1.00/
*
      DATA (CE(8,J),J=191,300)/
     &   0.00,-0.05,-0.06, 0.03, 0.08,-0.10,-0.02, 0.16,-0.16, 0.07,
     &   0.10,-0.13,-0.07, 0.41, 0.35, 0.10, 0.48,-0.48, 0.05, 1.00,
     &  -0.01, 0.05, 0.06,-0.05,-0.06, 0.12, 0.05,-0.16, 0.17,-0.06,
     &  -0.04, 0.18, 0.12,-0.37,-0.40,-0.14,-0.36, 0.56, 0.04,-0.96,
     &   1.00, 0.02, 0.03, 0.00, 0.06,-0.03, 0.00,-0.08,-0.01, 0.02,
     &   0.14, 0.01, 0.03,-0.26, 0.02, 0.04, 0.46,-0.13,-0.06,-0.82,
     &  -0.00, 0.05, 1.00, 0.03, 0.03, 0.03, 0.01,-0.09, 0.02,-0.05,
     &  -0.10, 0.06,-0.05,-0.20,-0.04,-0.06,-0.30,-0.10, 0.04,-0.54,
     &   0.09,-0.31,-0.68, 0.46,-0.03, 1.00,-0.02, 0.04, 0.05,-0.04,
     &  -0.02, 0.10, 0.05,-0.11, 0.14,-0.00, 0.06, 0.20, 0.09,-0.21,
     &  -0.33,-0.08,-0.12, 0.50, 0.09,-0.68, 0.84, 0.21, 0.06, 1.00/
*
      DATA ((P(9,J,K),K=1,3),J=1,8)/
     &   6.18E+5, 1.00E-1, 4.09E-2, 1.42E+0,-5.10E-2, 2.54E-1,
     &   9.08E+4, 2.03E-1,-1.29E+0, 4.03E+0,-6.53E-1, 7.33E-1,
     &   5.64E+2, 7.09E-1,-2.51E-1, 2.07E+1,-1.10E-1, 4.84E-1,
     &   5.88E+1, 8.84E-1,-2.58E-1, 6.78E+1, 1.99E-1, 3.38E-1/
*
      DATA ((DP(9,J,K),K=1,3),J=1,8)/
     &   7.77E+3, 1.94E-1, 3.82E-1, 2.01E-3, 1.15E-1, 4.14E-1,
     &   3.98E+4, 2.02E+0, 6.88E-1, 7.94E-1, 1.18E+0, 7.46E-1,
     &   6.42E+0, 3.98E-1, 3.00E+0, 1.82E+0, 5.40E+0, 7.61E-1,
     &   1.51E+0, 1.77E-1, 5.13E-1, 1.41E+0, 6.93E-1, 2.00E-1/
*
      DATA (CE(9,J),J=1,190)/
     &   1.00,-0.01, 1.00,-0.78, 0.25, 1.00,-0.16,-0.04, 0.12, 1.00,
     &   0.07, 0.43, 0.04,-0.28, 1.00, 0.06,-0.07,-0.20,-0.80,-0.25,
     &   1.00,-0.31, 0.04, 0.25,-0.85, 0.18, 0.75, 1.00, 0.13, 0.00,
     &  -0.11, 0.09, 0.79,-0.58,-0.21, 1.00,-0.14, 0.00, 0.12,-0.12,
     &  -0.77, 0.61, 0.25,-1.00, 1.00, 0.12, 0.13,-0.13, 0.27,-0.31,
     &   0.04,-0.30,-0.38, 0.39, 1.00,-0.06, 0.06,-0.02,-0.33, 0.72,
     &  -0.03, 0.33, 0.66,-0.63, 0.00, 1.00,-0.23, 0.13, 0.17,-0.41,
     &  -0.25, 0.67, 0.58,-0.63, 0.67, 0.57, 0.13, 1.00,-0.19,-0.01,
     &   0.15,-0.46, 0.17, 0.35, 0.57,-0.01, 0.03,-0.32, 0.28, 0.27,
     &   1.00, 0.12,-0.09,-0.17, 0.15, 0.29,-0.32,-0.25, 0.51,-0.52,
     &  -0.05, 0.39,-0.38,-0.31, 1.00,-0.17, 0.10, 0.20,-0.30,-0.16,
     &   0.41, 0.42,-0.44, 0.45, 0.12,-0.11, 0.56, 0.55,-0.90, 1.00,
     &   0.13, 0.02,-0.09, 0.30,-0.10,-0.23,-0.38,-0.00,-0.01, 0.35,
     &  -0.12,-0.08,-0.87, 0.23,-0.35, 1.00,-0.03,-0.04,-0.03,-0.16,
     &   0.31,-0.00, 0.16, 0.34,-0.32, 0.01, 0.57, 0.07, 0.32, 0.63,
     &  -0.28,-0.21, 1.00,-0.16, 0.08, 0.16,-0.28,-0.06, 0.35, 0.40,
     &  -0.29, 0.31, 0.15, 0.07, 0.53, 0.61,-0.70, 0.90,-0.40,-0.04,
     &   1.00,-0.06,-0.01, 0.04,-0.14, 0.06, 0.10, 0.17, 0.01,-0.01,
     &  -0.11, 0.11, 0.07, 0.44,-0.08, 0.18,-0.63, 0.26, 0.29, 1.00/
*
      DATA (CE(9,J),J=191,300)/
     &   0.04,-0.03,-0.06, 0.04, 0.11,-0.10,-0.07, 0.18,-0.18, 0.01,
     &   0.17,-0.10,-0.14, 0.45,-0.37, 0.17, 0.50,-0.42,-0.09, 1.00,
     &  -0.05, 0.04, 0.06,-0.08,-0.07, 0.12, 0.12,-0.16, 0.16, 0.08,
     &  -0.05, 0.20, 0.19,-0.39, 0.43,-0.10,-0.25, 0.58, 0.14,-0.90,
     &   1.00, 0.01, 0.02,-0.01, 0.02, 0.02,-0.02,-0.03, 0.02,-0.01,
     &   0.21, 0.12, 0.12,-0.19, 0.12,-0.01, 0.50, 0.21, 0.09,-0.60,
     &   0.19, 0.13, 1.00, 0.01,-0.00, 0.01, 0.04,-0.10,-0.00,-0.05,
     &  -0.09, 0.09,-0.16,-0.27,-0.14,-0.01,-0.25, 0.04,-0.19,-0.60,
     &  -0.12,-0.06,-0.57, 0.16,-0.63, 1.00,-0.04, 0.03, 0.04,-0.08,
     &   0.02, 0.08, 0.11,-0.04, 0.05, 0.19, 0.16, 0.24, 0.11,-0.09,
     &   0.26, 0.11, 0.24, 0.49, 0.06,-0.26, 0.65, 0.65,-0.58, 1.00/
*
      DATA ISTART,PNRGSV/1,0./
*
*----------------------------------------------------------------------*
*
      INCP=10010
      INCP=itip
*
*      TYPE *,INCP
*      TYPE *,PNRG,ATARG,ANGLE,ESECND,XSECT,DXSECT,
*       *  SIGT,SIGNE,SIGS,DSIGS,ESCAT,ETARG
*
*
      IF(ISTART.EQ.0) GO TO 10
*
*      INITIALIZE PARAMETERS
*      NO. OF TARGET MESH POINTS, A=12 TO 238
*
      JA=10
*     NO. OF PRIMARY FITTING PARAMETERS
*
      JP=8
*     NO. OF LEGENDRE TERMS
*
      JT=3
*     NO. OF GLOBAL PARAMETERS PER INCIDENT ENERGY AND TARGET
*
      JG=24
*     NO. OF PACKED CORRELATION MATRIX TERMS (LOWER TRIANGULAR OF 24X24
*
      JC=300
*     OTHER INITIALIZATIONS
*
      PI2=2.*3.14159
      AMIN=6.
      AMAX=265.
      EMIN=0.005
      EMAX=1000.001
      EREF=590.
      EZERO=100.
*
*     EXTRAPOLATE PARAMETERS TO ATARG=6 AND 265
*
      DO 5 J=1,JP
*
*     FOR AVERAGE AMPLITUDE USE LOG-LOG INTERPOLATION BUT FOR
*     ALL OTHERS USE LOG-LIN INTERPOLATION FOR ATARG VS PARAMETER.
*
      DO 5 K=1,JT
      I=3
      IF(MOD(J,2).EQ.1) I=5
*
      CALL TERP1(AMAS(2),P(2,J,K),AMAS(3),P(3,J,K),AMAS(1),P(1,J,K),I)
      CALL TERP1(AMAS(7),P(7,J,K),AMAS(9),P(9,J,K),AMAS(10),P(10,J,K),I)
*
    5 CONTINUE
      ISTART=0
   10 CONTINUE
*
*     IS ANGULAR, ENERGY INTEGRATED CROSS-SECTION WANTED?
*
      INTGRL=0
      IF(ANGLE.EQ.-2..AND.ESECND.EQ.-2.) INTGRL=1
*
   11 CONTINUE
*
*     IS PNRG OUTSIDE RANGE?
*
      IF(PNRG.LT.EMIN.OR.PNRG.GT.EMAX) GO TO 510
*
*     IS ESECND OUT OF RANGE?
*
      IF(ESECND.EQ.-2.) GO TO 12
      IF(ESECND.LT.0..OR.ESECND.GT.PNRG) GO TO 520
*
*     IS ATARG OUTSIDE RANGE?
*
   12 IF(ATARG.LT.AMIN.OR.ATARG.GT.AMAX) GO TO 530
*
*     TEST FOR NEW INCIDENT PROTON ENERGY
*
      IF(PNRG.EQ.PNRGSV) GO TO 30
*
*     COMPUTE NORMALIZATION FACTOR, RENORM, TO ENERGIES OTHER THAN
*     590 MEV. (TEMPORARY APPROXIMATION 1 NOV 1985)
*
   16 RENORM=1.
      IF(PNRG.EQ.EREF.AND.ATARG.EQ.ATARSV) GO TO 30
      RENORM=ALOG(PNRG/EZERO)/ALOG(EREF/EZERO)
*
*     EXTRAPOLATION TO LOW ENERGIES BASED ON ALICE CALCULATIONS
*     REVISED RENORM 1 JUL 1986.
*
      ESWICH=200.
      IF(ATARG.LE.200.) ESWICH=250.
      IF(ATARG.LE.100.) ESWICH=400.
      IF(NSWCH.GT.0) ESWICH=110.
      IF(PNRG.GE.ESWICH) GO TO 20
*
*     EMPIRICAL LOW ENERGY REDUCTION FACTOR IF PROTONS INCIDENT
*
      FACT=SQRT(PNRG/ESWICH)
*
*     EMPIRICAL LOW ENERGY REDUCTION FACTOR IF PROTONS INCIDENT
*
      IF(INCP.EQ.10) GO TO 18
      FACT=(PNRG/ESWICH)**(0.5*(1.+.3*(1.0-PNRG/ESWICH)))
   18 RENORM=ALOG(ESWICH/EZERO)/ALOG(EREF/EZERO)*FACT
   20 PNRGSV=PNRG
   30 CONTINUE
*
*     TEST FOR NEW TARGET
*
      IF(ATARG.EQ.ATARSV) GO TO 90
*
*      ARE INTERPOLATED VALUES OF MASS PARAMETERS NEEDED?
*
      ATARSV=ATARG
      JSET=0
      DO 40 J=1,JA
      IF(ABS((ATARG-AMAS(J))/ATARG).LE.0.05) JSET=J
      IF(ATARG.LE.AMAS(J)) GO TO 50
   40 CONTINUE
   50 IF(JSET.NE.0) GO TO 70
*
*     ATARG REQUESTED IS NOT ON ATARG MESH.  INTERPOLATED
*     PARAMETERS ARE NEEDED.
*
      JH=J
      JL=JH-1
      DO 60 J=1,JP
      I=3
      IF(MOD(J,2).EQ.1) I=5
      DO 60 K=1,JT
   60 CALL TERP1(AMAS(JL),P(JL,J,K),AMAS(JH),P(JH,J,K),ATARG,
     &  TEMP(J,K),I)
      IF(DXSECT.EQ.0.) GO TO 90
      I=3
      DO 62 J=1,JP
      DO 62 K=1,JT
   62 CALL TERP1(AMAS(JL),DP(JL,J,K),AMAS(JH),DP(JH,J,K),ATARG,
     &  TEMP1(J,K),I)
      DO 64 J=1,JC
   64 CALL TERP1(AMAS(JL),CE(JL,J),AMAS(JH),CE(JH,J),ATARG,
     &  COR(J),I)
      GO TO 90
   70 CONTINUE
*
*     ATARG REQUESTED IS ON ATARG MESH.  READ IN JSET VALUES.
*
      DO 80 J=1,JP
      DO 80 K=1,JT
   80 TEMP(J,K)=P(JSET,J,K)
      IF(DXSECT.EQ.0.) GO TO 90
      DO 82 J=1,JP
      DO 82 K=1,JT
   82 TEMP1(J,K)=DP(JSET,J,K)
      DO 84 J=1,JC
   84 COR(J)=CE(JSET,J)
   90 CONTINUE
*
C     BRANCH IF INTEGRATED CROSS-SECTION WANTED?
*
      IF(INTGRL.EQ.1) GO TO 350
*
*     BRANCH FOR ANGULAR INTEGRATED DIFFERENTIAL CROSS-SECTION
*     IN MICROBARNS/MEV
*
      IF(ANGLE.EQ.-2.) GO TO 115
*
*     TEST FOR NEW EMISSION ANGLE
*
      IF(ANGLE.EQ.ANGLSV) GO TO 95
*
*     CALCULATE LEGENDRE POLYNOMIALS
*
*
      DANGLE=ANGLE
      P1=DCOS(DANGLE)
      P2=1.5*P1*P1-0.5
      ANGLSV=ANGLE
*
*     ENERGY PARAMETERS
*     BASIC ENERGY RESOLUTION WIDTH, WID=7% PNRG.
*
   95 WID=.07*PNRG
*
*     CUT-OFF WIDTH PERCENTAGE=1%.  1/2 MAXIMUM AT (1-WIDCT)*PNRG.
*
      WIDCT=0.01
*
*     VARYING RESOLUTION WIDTH FOR ENERGY-CONSTRAINED NEUTRONS WID1.
*
      WID1=3.*WID*ABS(DSIN(DANGLE))
*
      IF(WID1.LT.WIDCT*PNRG) WID1=WIDCT*PNRG
*
*     RELATIVISTIC ENERGY PEAK FOR QUASI-ELASTICALLY SCATTERED NEUTRONS
*
      RESTE=938.3
      IF(INCP.EQ.00010) RESTE=939.6
      IF(INCP.EQ.10020) RESTE=1875.6
      RELAT=PNRG/RESTE
      FCT1=1.+RELAT/2.
      FCT2=100.
*
      IF(ANGLE.LE.89.) FCT2=(DSIN(DANGLE)/DCOS(DANGLE))*
     &                      (DSIN(DANGLE)/DCOS(DANGLE))
*
      PEAK=PNRG/2.*(1.+(1.-FCT1*FCT2)/(1.+FCT1*FCT2))
      IF((PNRG-PEAK).LE.1.5*WID) PEAK=PNRG-1.5*WID
  100 CONTINUE
*
*     CONSTRUCT ANGULAR DEPENDENT AMPLITUDE AND TEMPERATURE PARAMETERS
*
      RED=1.0
      IF(PNRG.LT.65.) RED=(PNRG+5.)/70.
      IF(RED.LT.1.) JP=6
      IF(RED.LT.1.) ISTART=1
      DO 110 J=1,JP
      FMULT=1.0
      IF(MOD(J,2).EQ.0) FMULT=RED
      IF(RED.LT.1..AND.J.EQ.5) FMULT=RED/2.
  110 PAR(J)=TEMP(J,1)*FMULT*(1.+TEMP(J,2)*P1+TEMP(J,3)*P2)
  115 CONTINUE
      IF(ESECND.EQ.-2.) GO TO 270
      IF(ESECND.LE.PNRG) GO TO 200
      XSECT=0.
      GO TO 300
*
*     CALCULATE CROSS-SECTION IN 4 TERMS
*
  200 XSECT=0.
*
*     BRANCH FOR ANGULAR INTEGRATED CROSS-SECTION
*
      IF(ANGLE.NE.-2.) GO TO 220
*
*     CALCULATE DOUBLE DIFFERENTIAL CS AT 30, 60, AND 90 DEGREES.
*
      S(8,1)=0.886
      S(8,2)=0.
      S(8,3)=-0.886
      DO 210 JTMP1=1,JT
      U=S(8,JTMP1)
      P1=U
*
      P2=1.5*U*U-0.5
*
      DO 205 JTMP2=1,JP
  205 PAR(JTMP2)=TEMP(JTMP2,1)*(1.+TEMP(JTMP2,2)*P1+TEMP(JTMP2,3)*P2)
      S(7,JTMP1)=0.
      DO 208 JTMP2=1,JP,2
      IF((ESECND/PAR(JTMP2+1)).GT.20.) GO TO 208
      S(7,JTMP1)=S(7,JTMP1)+PAR(JTMP2)*ESECND*EXP(-ESECND/PAR(JTMP2+
     &  1))
  208 CONTINUE
  210 CONTINUE
*
      XSECT=2./9.*S(7,1)+2./9.*S(7,3)+5./9.*S(7,2)
      XSECT=XSECT*PI2*2.*RENORM
      GO TO 264
*
  220 CONTINUE
      IF(ESECND.EQ.0.) GO TO 264
      DO 250 J=1,JP,2
      IF(PAR(J).LT.0.) PAR(J)=0.
      IF((ESECND/PAR(J+1)).GT.20.) GO TO 250
      XSECT=XSECT+PAR(J)*ESECND*EXP(-ESECND/PAR(J+1))
*
  250 CONTINUE
*
*     ADD=ENERGY CONSTRAINED EVAPORATION NEUTRONS.  AREA NOT AFFECTED BY
*
      TMP2=(ESECND-PEAK)/WID1
      TMP2=ABS(TMP2)
      TMP1=PNRG/PAR(JP)
*
      AREA=PAR(JP)*PAR(JP)*EXP(-TMP1)*(1.+TMP1)
      ADD=PAR(JP-1)*AREA/WID1*EXP(-TMP2)
     &/((1.+EXP(-TMP2))*(1.+EXP(-TMP2)))
*
      XSECT=XSECT+ADD
      IF(ESECND.GT.(5.*PAR(JP-2))) GO TO 260
      TMP1=PNRG/PAR(JP-2)
*
      AREA=PAR(JP-2)*PAR(JP-2)*EXP(-TMP1)*(1.+TMP1)
      ADD=PAR(JP-3)*AREA/WID1*EXP(-TMP2)
     &/((1.+EXP(-TMP2))*(1.+EXP(-TMP2)))
*
      XSECT=XSECT+ADD
  260 CONTINUE
*
      CUTOFF=1./(1.+EXP(-1./WIDCT*(1.-ESECND/(PNRG*(1.-WIDCT)))))
      XSECT=XSECT*CUTOFF*RENORM
      IF(DXSECT.EQ.0.) GO TO 264
      DO 261 J=1,JP,2
      PART=PAR(J)*ESECND*EXP(-ESECND/PAR(J+1))
      S(J,1)=PART/TEMP(J,1)
      S(J,2)=TEMP(J,1)*P1*ESECND*EXP(-ESECND/PAR(J+1))
      S(J,3)=TEMP(J,1)*P2*ESECND*EXP(-ESECND/PAR(J+1))
      S(J+1,1)=PART*ESECND/PAR(J+1)/TEMP(J+1,1)
*
      S(J+1,2)=PART*ESECND/PAR(J+1)*PAR(J+1)*TEMP(J+1,1)*P1
      S(J+1,3)=PART*ESECND/PAR(J+1)*PAR(J+1)*TEMP(J+1,1)*P2
*
  261 CONTINUE
*
      DXSQ=0.
      DO 263 J=1,JG
      DO 263 K=1,J
      L=(J-1)/3+1
      M=J-(L-1)*3
      L1=(K-1)/3+1
      M1=K-(L1-1)*3
      N=J*(J-1)/2+K
      FACT=1.
*
      IF(J.NE.K) FACT=2.
      DXSQ=DXSQ+FACT*S(L,M)*S(L1,M1)*COR(N)*
     &  TEMP1(L,M)*TEMP1(L1,M1)
*
  263 CONTINUE
      DXSECT=SQRT(DXSQ)
*
  264 CONTINUE
*
      GO TO 290
*
  270 XSECT=0.
*
      DO 280 J=1,JP,2
      IF(PAR(J).LT.0.) PAR(J)=0.
*
      XSECT=XSECT+PAR(J)*PAR(J+1)*PAR(J+1)
*
  280 CONTINUE
      XSECT=XSECT*RENORM
*
  290 IF(SIGT.GE.0.) CALL SIG(PNRG,ATARG,SIGT,SIGNE,SIGS)
*
      IF(ANGLE.GE.0.) CALL DSDA(PNRG,ATARG,ANGLE,SIGS,DSIGS,ESCAT,ETARG
     &  )
*
      IF(ESECND.GT.PNRG) GO TO 300
*
  300 CONTINUE
*
      RETURN
*
*     ANGLE, ENERGY INTEGRATED CROSS-SECTION. XSECT (MICROBARNS)
*
  350 CONTINUE
      XSECT=0.
      DO 360 K=1,JP,2
      J=K/2+1
*
*     T1 IS THE JTH TERM CROSS-SECTION IF ISOTROPIC
*
      T1=PI2*TEMP(K,1)*TEMP(K+1,1)*TEMP(K+1,1)
      TOT1=2.+2./3.*TEMP(K+1,2)*TEMP(K+1,2)
     &+2./5.*TEMP(K+1,3)*TEMP(K+1,3)
*
      TOT2=TEMP(K,2)*(4./3.*TEMP(K+1,2)+8./15.*TEMP(K+1,2)*TEMP(K+1,3))
*
      TOT3=TEMP(K,3)*(4./5.*TEMP(K+1,3)+4./15.*TEMP(K+1,2)*TEMP(K+1,2)
     &+4./35.*TEMP(K+1,3)*TEMP(K+1,3))
*
      XSECT=XSECT+T1*(TOT1+TOT2+TOT3)
      IF(DXSECT.EQ.0.) GO TO 360
      T2=T1/TEMP(K,1)
      T3=2.*T1/TEMP(K+1,1)
      S(K,1)=T2*(TOT1+TOT2+TOT3)
      S(K,2)=T1*TEMP(K+1,2)*(4./3.+8./15.*TEMP(K+1,3))
*
      S(K,3)=T1*(4./5.*TEMP(K+1,3)+4./15.*TEMP(K+1,2)*TEMP(K+1,2)
     &+4./35.*TEMP(K+1,3)*TEMP(K+1,3))
*
      S(K+1,1)=T3*(TOT1+TOT2+TOT3)
      S(K+1,2)=T1*(4./3.*TEMP(K+1,2)+4./3.*TEMP(K,2)+
     &  8./15.*TEMP(K,2)*TEMP(K+1,3)+8./15.*TEMP(K,3)*TEMP(K+1,2))
      S(K+1,3)=T1*(4./5.*TEMP(K+1,3)+8./15.*TEMP(K,2)*TEMP(K+1,2)+
     &  4./5.*TEMP(K,3)+8./35.*TEMP(K,3)*TEMP(K+1,3))
*
  360 CONTINUE
*
      XSECT=XSECT*RENORM
      INTGRL=0
      IF(DXSECT.EQ.0.) GO TO 375
      DXSQ=0.
      DO 370 J=1,JG
      DO 370 K=1,J
      L=(J-1)/3+1
      M=J-(L-1)*3
      L1=(K-1)/3+1
      M1=K-(L1-1)*3
      N=J*(J-1)/2+K
      FACT=1.
*
      IF(J.NE.K) FACT=2.
      DXSQ=DXSQ+FACT*S(L,M)*S(L1,M1)*COR(N)*
     &  TEMP1(L,M)*TEMP1(L1,M1)
*
  370 CONTINUE
      DXSECT=SQRT(DXSQ)
      DXSECT=DXSECT*RENORM
  375 CONTINUE
*
*     INCLUDE NONELASTIC CROSS-SECTION AS CALCULATED FROM LETAW +
*     IN ASTROPHYS. JOURNAL SUPP. SER. 51,271-276,1983 AND YIELD
*
      CALL SIG(PNRG,ATARG,SIGT,SIGNE,SIGS)
*
*
      IF(INCP.EQ.10020)
     &  CALL DSDA(PNRG,ATARG,ANGLE,SIGS,DSIGS,ESCAT,ETARG)
*
      YIELD=XSECT/SIGNE*1.0E-6
      ESECND=YIELD
*
      RETURN
*
  510 WRITE(6,1010)PNRG,EMIN,EMAX
*
      RETURN
*
  520 WRITE(6,1020)ESECND,PNRG
*
      RETURN
*
*
  530 WRITE(6,1022)ATARG,AMIN,AMAX
*
*
 1010 FORMAT(1X,F8.2,' PROTON ENERGY NOT BETWEEN ',F8.2,' AND ',
     &  F8.2,' MEV.')
 1020 FORMAT(1X,F8.2,' NEUTRON ENERGY NOT LESS THAN ',F8.2,
     &  ' INCIDENT PROTON ENERGY.')
 1022 FORMAT(1X,F8.2,' TARGET MASS NOT BETWEEN ',F8.2,' AND ',
     &  F8.2,' AMU.')
 1030 FORMAT(1X,'INC. PROTON   TARGET MASS     ANGLE       NEUTRON',
     &  '   CROSS-SECTION',/,
     &  'ENERGY (MEV)    (AMU)         (DEG)    ENERGY (MEV)',
     &  '(MICROB/SR-MEV)')
 1035 FORMAT(1X,'INC. PROTON   TARGET MASS     ANGLE       NEUTRON',
     &  '   CROSS-SECTION',/,
     &  'ENERGY (MEV)    (AMU)         (DEG)    ENERGY (MEV)',
     &  '(MICROB/MEV)')
 1040 FORMAT(1X,8E13.4)
*
      RETURN
      END
