************************************************************************
*                                                                      *
      subroutine sigrc(incp,emev,ia,iz,sigt,sigr,sigs)
*                                                                      *
*        calculates total, nonelastic and elastic cross-sections       *
*                                                                      *
*     input:                                                           *
*        incp   : =1, proton, =2, neutron                              *
*        emev   : incident nucleon energy (MeV)                        *
*        ia     : mass number                                          *
*        iz     : charge number                                        *
*                                                                      *
*     output:                                                          *
*       sigt    : total cross-section (b)                              *
*       sigr    : nonelastic cross-section (b)                         *
*       sigs    : sigt-sigr=elastic scattering cross-section (b)       *
*                                                                      *
************************************************************************

      dimension       par(4),c(4,3)

      data (c(1,k),k=1,3)/1.353,0.4993,1.076/
      data (c(2,k),k=1,3)/0.6653,0.9900,1.040/
      data (c(3,k),k=1,3)/2.456,2.060,0.9314/
      data (c(4,k),k=1,3)/0.1167,1.623,0.9736/

*-----------------------------------------------------------------------

         rz = 0.14

         a = float(ia)
         z = float(iz)

         a13 = a**0.3333333
         a23 = a**0.6666667
         alg = log(a)

         ecst = 82.0
         acst = 238.0

*-----------------------------------------------------------------------

         c1 =  0.0825
         c2 = -0.0057
         c3 =  0.14
         c4 = -0.2
         c5 =  2.72
         c6 =  1.62
         c7 = -5.3

*-----------------------------------------------------------------------

         ap = 1.0
         pi = 3.1415927

*-----------------------------------------------------------------------
*     modified by Niita
*-----------------------------------------------------------------------

            cmev = 0.0575 * a + 12.31

            facp = min( 1.0, 0.684 + 1.327e-3 * a )
            facc = 1.0 - facp

*-----------------------------------------------------------------------

            g1 = 1.0 - 0.62 * exp( -cmev / 200. )
     &                      * sin( 10.9 / cmev**0.28 )
            g1 = g1 * 1.1
            g2 = 1.0 + 0.016 * sin( 5.3 - 2.63 * log(a) )

            sigpa = 0.045 * a**0.7 * g1 * g2

*-----------------------------------------------------------------------

            eroot = sqrt(cmev)
            rad   = rz * a**0.3333
            wvl   = 0.1 * 1.22 * ( a + ap ) / a * sqrt(14.1) / eroot

            sigcr = pi * ( rad + wvl )**2

*-----------------------------------------------------------------------

            sigpc = facp * sigcr + facc * sigpa

            ftpa = sigpc / sigpa
            ftcr = sigpc / sigcr

            enpa = ftpa * 1.1 - 1.0

*-----------------------------------------------------------------------

         do k=1,4

            par(k) = log(c(k,1))+log(c(k,2))*alg+log(c(k,3))*alg**2
            par(k) = exp(par(k))

         end do

            epk   = par(3) * a13
            fexp1 = par(2) * log(epk/cmev)

            sigtp  = sigpc * ( 1.0 + par(4) )
     &             + par(1) * a13 * exp( -fexp1**2 )

            esub = ecst * a13 / acst**0.3333
            epk2 = epk - esub

         if( epk2 .gt. 0.0 ) then

            fexp2 = par(2) * log( epk2 / cmev )

            sigtp = sigtp + par(1) * a13 * exp( -fexp2**2 )

         end if

*-----------------------------------------------------------------------

            if( eroot .lt. 3.0 ) as = 1.0 - c1 * ( 3.0 - eroot )**2
            if( eroot .ge. 3.0 ) as = 1.0

            p = c2 * eroot + c3
            q = c4 * eroot + c5

            if( eroot .ge. 4.0 ) r = 1.2
            if( eroot .lt. 4.0 ) r = c6 * eroot + c7

            sigtc = 2.0 * sigpc * ( as - p * cos( q * a**0.3333 - r ) )

*-----------------------------------------------------------------------

            facp = min( 1.0, 0.578 + 1.77e-3 * a )
            facc = 1.0 - facp

            sigtpc = facp * sigtc + facc * sigtp

            fttp = sigtpc / sigtp
            fttc = sigtpc / sigtc

*-----------------------------------------------------------------------
*     calculation of sigr as
*     J.Letaw etal., Astrophys. J. Supp. series 51,271-276(1983).
*     sigrb = asymptotic high energy reaction cross-section
*-----------------------------------------------------------------------

         sigrb = 0.045 * a**0.7

*-----------------------------------------------------------------------
*     energy dependent factor
*-----------------------------------------------------------------------

         f1 = 1.0 - 0.62 * exp( -emev / 200. )
     &                   * sin( 10.9 / emev**0.28 )

*-----------------------------------------------------------------------
*     Pearlstein added low energy enhancement factor of 10%
*-----------------------------------------------------------------------

         f1 = f1 * ( 1.0 + enpa * exp( -( emev - cmev ) / 10. ) )


c        f1 = f1 * ( 1.0 + 0.1 * exp( -( emev - 20. ) / 10. ) )

*-----------------------------------------------------------------------
*     mass dependent factor
*-----------------------------------------------------------------------

         f2 = 1.0 + 0.016 * sin( 5.3 - 2.63 * log(a) )

*-----------------------------------------------------------------------

         sigr = sigrb * f1 * f2

*-----------------------------------------------------------------------
*     sigt according to fit by S. Pearlstein, June 86.
*-----------------------------------------------------------------------

      if( emev .ge. cmev ) then

         do 210 k=1,4

            par(k) = log(c(k,1))+log(c(k,2))*alg+log(c(k,3))*alg**2
            par(k) = exp(par(k))

  210    continue

            epk   = par(3) * a13
            fexp1 = par(2) * log(epk/emev)

            sigt  = sigr * ( 1.0 + par(4) )
     &            + par(1) * a13 * exp( -fexp1**2 )

            ecst = 82.0
            acst = 238.
            esub = ecst * a13 / acst**0.3333
            epk2 = epk - esub

         if( epk2 .gt. 0.0 ) then

            fexp2 = par(2) * log( epk2 / emev )

            sigt = sigt + par(1) * a13 * exp( -fexp2**2 )

         end if

            factp = 1.0 + ( fttp - 1.0 )
     &            * exp( - ( emev - cmev ) / 10.0 )

            sigt = sigt * factp

*-----------------------------------------------------------------------
*     calculates xsects according to Ramsauer effect
*     ref: Angeli and Csikai, NP A170,577-583(1971)
*     sigt/signe=as-p*cos(q*a**0.3333-r)
*-----------------------------------------------------------------------

      else

            eroot = sqrt(emev)

            if( eroot .lt. 3.0 ) as = 1.0 - c1 * ( 3.0 - eroot )**2
            if( eroot .ge. 3.0 ) as = 1.0

            p = c2 * eroot + c3
            q = c4 * eroot + c5

            if( eroot .ge. 4.0 ) r = 1.2
            if( eroot .lt. 4.0 ) r = c6 * eroot + c7

            rad = rz * a**0.3333
            wvl = 0.1 * 1.22 * ( a + ap ) / a * sqrt(14.1) / eroot

         facr = 1.0 + ( ftcr - 1.0 ) * exp( - ( cmev - emev ) / 10.0 )

            sigr = pi * ( rad + wvl )**2 * facr
            sigt = 2.0 * sigr * ( as - p * cos( q * a**0.3333 - r ) )

            factc = 1.0 + ( fttc - 1.0 )
     &            * exp( - ( cmev - emev ) / 10.0 )

            sigt = sigt * factc

      end if

*-----------------------------------------------------------------------
*     coulomb factor
*     ec, coulomb barrier half-height, similar to s. pearlstein,
*     j. nuc. energy 23,87(1975) using optical model inverse p cs's.
*-----------------------------------------------------------------------

      if( incp .eq. 1 .and. emev .lt. 200.0 ) then

            ec = 1.44 * z / ( 8.2 + 0.68 * a13 )

            w1    = 3.816 + 0.1974 * z
            fexc1 = exp( ( ec - emev ) / w1 )
            qfac1 = 1.0 / ( 1.0 + fexc1 )

            w2    = 0.07246 * z + 6.058
            if( z .lt. 10.0 ) w2 = 12.0
            qfac2 =  1.0 - exp( - ( emev / w2 )**2 )

            w3    = 2.0
            fexc3 = exp( ( ec - emev ) / w3 )
            qfac3 = 1.0 / ( 1.0 + fexc3 )

            fcoul = qfac1 * qfac2 * qfac3

            sigt = sigt * fcoul
            sigr = sigr * fcoul

      end if

*-----------------------------------------------------------------------

            sigs = sigt - sigr

*-----------------------------------------------------------------------

      return
      end
