************************************************************************
*                                                                      *
      SUBROUTINE SYSCON(E,A,ANGLE,VK,ANGZLM,ESCAT,CONV)
*                                                                      *
*     TO CONVERT FROM LAB PARAMETERS TO ZERO LINEAR MOMENTUM (ZLM)     *
*     FRAME FOR RELATIVISTIC FORMULAE,                                 *
*     SEE J.L. FOWLER, J.E. BROLLEY, JR.,                              *
*     REV. MOD. PHYS. 28,103-134(1956)                                 *
*                                                                      *
*     INPUT:                                                           *
*       E=INCIDENT ENERGY IN LAB (MEV)                                 *
*       ANGLE=LAB SCATTERING ANGLE (DEG)                               *
*     OUTPUT:                                                          *
*          VK=WAVE NUMBER (1/CM)                                       *
*      ANGZLM=SCATTERING ANGLE IN ZLM SYSTEM (DEG)                     *
*       ESCAT=ELASTIC SCATTERING ENERGY IN LAB (MEV)                   *
*        CONV=FACTOR TO CONVERT CROSS-SECTION FROM C.M. TO ZLM SYSTEM  *
*                                                                      *
************************************************************************
*
      COMMON /INCP/   INCP
*
*-----------------------------------------------------------------------
*
      PI=3.1415927
      RMASS=938.3
      IF(INCP.EQ.00010) RMASS=939.6
      IF(INCP.EQ.10020) RMASS=1875.6
      ANG=ANGLE*PI/180.
      RAT=E/RMASS
      GZ=1.+RAT
      S=1.+2.*A*GZ+A**2
      GCG=(A+GZ)/SQRT(S)
      G1=(1.+A*GZ)/SQRT(S)
      A1=(1.+A*GZ)/(A+GZ)/A
      C3=GCG**2
      C1=-A1*C3
      C2=(A1**2-1.)*C3
      IF(ABS(ANG-PI/2.).GE.1.E-2) GO TO 10
      COSA=C1/C3
      GO TO 20
   10 CONTINUE
      TANX=SIN(ANG)/COS(ANG)
      SIGN=1.
      IF(ANG.GT.(PI/2.)) SIGN=-1.
      X2=TANX**2
      COSA=(C1*X2+SIGN*SQRT(1.-C2*X2))/(1.+C3*X2)
      IF(ANGLE.GE.179.) COSA=-1.
      IF(ANGLE.LE.0.1) COSA=1.
   20 CONTINUE
      ANGZLM=ACOS(COSA)
      ANGZLM=ANGZLM*180./PI
      IF(ABS(ANG-PI/2.).GE.0.02) GO TO 30
      ANG1=ANG-0.1
      ANG2=ANG+0.1
      COSX1=COS(ANG1)
      COSX2=COS(ANG2)
      X31=COSX1**3
      X32=COSX2**3
      X21=(SIN(ANG1)/COS(ANG1))**2
      X22=(SIN(ANG2)/COS(ANG2))**2
      CONV=1./2.*((-2.*C1/X31+SIGN*C2/X31/SQRT(1.-C2*X21))/(1.+C3*X21)+
     &  2.*C3/X31*(C1*X21+SIGN*SQRT(1.-C2*X21))/(1.+C3*X21)**2+
     &  (-2.*C1/X32-SIGN*C2/X32/SQRT(1.-C2*X22))/(1.+C3*X22)+
     &  2.*C3/X32*(C1*X22+SIGN*SQRT(1.-C2*X22))/(1.+C3*X22)**2)
      GO TO 40
   30 CONTINUE
      COSX=COS(ANG)
      X3=COSX**3
      CONV=(-2.*C1/X3+SIGN*C2/X3/SQRT(1.-C2*X2))/(1.+C3*X2)+
     &  2.*C3/X3*(C1*X2+SIGN*SQRT(1.-C2*X2))/(1.+C3*X2)**2
   40 CONTINUE
      IF(ABS(CONV).LE.1.E-6) CONV=0.
      IF(ABS(A-1.).LE.0.01.AND.ANG.GE.(PI/2.-1.E-4)) CONV=0.
      ESCAT=RMASS*(GZ-1.)/S*(1.+A*(GZ-1.+(GZ+1.)*COSA)+
     &  A**2)
*
*      IF NONRELATIVISTIC, WAVE NUMBER IN LAB, VK
*
      VK=2.197E+12*SQRT(E)
      IF(INCP.EQ.10020) VK=VK/SQRT(2.)
*
*      CORRECTED FOR RELATIVISTIC AND ZLM MOTION
*
      ADD=1.
      IF(INCP.EQ.10020) ADD=2.
      VK=VK*A/(A+ADD)*SQRT((1.+RAT/2.)/(1.+RAT)**2)
*
      RETURN
      END
