************************************************************************
*                                                                      *
      subroutine syscrc(icm,incp,e,a,angle,vk,angzlm,escat,conv)
*                                                                      *
*        to convert from lab parameters                                *
*        to zero linear momentum (zlm) frame                           *
*        for relativistic formulae,                                    *
*        see J.L. Fowler, J.E. Brolley, Jr.,                           *
*        Rev. Mod. Phys. 28,103-134(1956)                              *
*                                                                      *
*     input:                                                           *
*        icm      : 0 -> cm, 1 -> lab  input and output                *
*        incp     : 1->proton, 2->neutron                              *
*        e        : incident energy in lab (MeV)                       *
*        angle    : scattering angle (deg) cm or lab                   *
*                                                                      *
*     output:                                                          *
*        vk       : wave number (1/cm) in lab                          *
*        angzlm   : scattering angle in cm system (deg)                *
*        escat    : elastic scattering energy in lab (MeV)             *
*        conv     : factor to convert cross-section from c.m.          *
*                   to lab system                                      *
*                                                                      *
************************************************************************

      implicit real*8 (a-h,o-z)

      pi = 3.1415927

*-----------------------------------------------------------------------

            if( incp .eq. 1 ) then

               rmass = 938.3

            else if( incp .eq. 2 ) then

               rmass = 939.6

            end if

            ang = angle * pi / 180.
            rat = e / rmass
            gz  = 1. + rat
            s   = 1. + 2. * a * gz + a**2

*-----------------------------------------------------------------------
*     if nonrelativistic, wave number in lab, vk
*-----------------------------------------------------------------------

            vk = 2.197e+12 * dsqrt(e)

*-----------------------------------------------------------------------
*     corrected for relativistic and zlm motion
*-----------------------------------------------------------------------

            add = 1.
            vk  = vk * a / ( a + add )
     &          * dsqrt( ( 1. + rat / 2. ) / ( 1. + rat )**2 )

*-----------------------------------------------------------------------

         if( icm .eq. 0 ) then

            angzlm = angle

            cosa = cos( angzlm * pi / 180. )
            conv = 1.0

*-----------------------------------------------------------------------

         else

               gcg=(a+gz)/dsqrt(s)
               g1=(1.+a*gz)/dsqrt(s)
               a1=(1.+a*gz)/(a+gz)/a
               c3=gcg**2
               c1=-a1*c3
               c2=(a1**2-1.)*c3
               if(dabs(ang-pi/2.).ge.1.e-2) go to 10
               cosa=c1/c3

               go to 20

   10          continue
               tanx=dsin(ang)/dcos(ang)
               sign=1.
               if(ang.gt.(pi/2.)) sign=-1.
               x2=tanx**2
               cosa=(c1*x2+sign*dsqrt(1.-c2*x2))/(1.+c3*x2)
               if(angle.ge.179.) cosa=-1.
               if(angle.le.0.1) cosa=1.

   20          continue

               angzlm=acos(cosa)

               angzlm=angzlm*180./pi

               if(dabs(ang-pi/2.).ge.0.02) go to 30

               ang1=ang-0.1
               ang2=ang+0.1
               cosx1=dcos(ang1)
               cosx2=dcos(ang2)
               x31=cosx1**3
               x32=cosx2**3
               x21=(dsin(ang1)/dcos(ang1))**2
               x22=(dsin(ang2)/dcos(ang2))**2
               conv=1./2.*((-2.*c1/x31+sign*c2/x31
     &              /dsqrt(1.-c2*x21))/(1.+c3*x21)
     &              +2.*c3/x31*(c1*x21
     &              +sign*dsqrt(1.-c2*x21))/(1.+c3*x21)**2
     &              +(-2.*c1/x32-sign*c2/x32/dsqrt(1.-c2*x22))
     &              /(1.+c3*x22)+2.*c3/x32
     &              *(c1*x22+sign*dsqrt(1.-c2*x22))/(1.+c3*x22)**2)

               go to 40

   30          continue

               cosx=dcos(ang)
               x3=cosx**3

               conv=(-2.*c1/x3+sign*c2/x3/dsqrt(1.-c2*x2))/(1.+c3*x2)+
     &           2.*c3/x3*(c1*x2+sign*dsqrt(1.-c2*x2))/(1.+c3*x2)**2

   40          continue

               if(dabs(conv).le.1.e-6) conv=0.
cKN
               if(conv.le.0.0) conv=1.
cKN
               if(dabs(a-1.).le.0.01.and.ang.ge.(pi/2.-1.e-4)) conv=0.

         end if

*-----------------------------------------------------------------------

         escat = rmass * ( gz - 1. )
     &         / s * ( 1. + a * ( gz - 1. + ( gz + 1. ) * cosa )
     &                    + a**2 )

*-----------------------------------------------------------------------

      return
      end
