************************************************************************
*                                                                      *
      SUBROUTINE TOTELA(EX,IZ,IA,NINC,IOPT,SIGTOT,SIGELA,SIGNON)
*                                                                      *
*                                                                      *
*     CALCULATION OF FISSION PROBABILITY                               *
*         = (FISSION CROSS SECTION)/(NON-ELASTIC CROSS SECTION)        *
*                                                                      *
*     VALIABLES                                                        *
*          EX    :  EXICITATION ENERGY [MEV]                           *
*          IZ    :  ATOMIC NUMBER OF TARGET                            *
*          IA    :  MASS NUMBER OF TARGET                              *
*          NINC  :  IDENTIFICATION FOR INCIDENT PARTICLES              *
*                     NINC=1  NEUTRON                                  *
*                     NINC=2  PROTON                                   *
*                     NINC=OTHERS  NOW NOT CALCULATING                 *
*          IOPT  :  OPTION OF FOMULA                                   *
*                     IOPT=1  PEALSTEIN                                *
*                     IOPT=2  NASA                                     *
*                     IOPT=3  WELLISH  (ONLY SIGNON)                   *
*          SIGTOT:  TOTAL CROSS SECTION (NEUTRON ONLY) [B]             *
*          SIGELA:  ELASTIC CROSS SECTION [B]                          *
*          SIGNON:  NON-ELASTIC CROSS SECTION [B]                      *
*                                                                      *
*     HISTORY                                                          *
*          1999.05  CREATED BY T.FUKAHORI (JAERI)                      *
*                                                                      *
************************************************************************
*
      REAL*8 SGREAC
*
      SIGTOT=0.0
      SIGELA=0.0
      SIGNON=0.0
      IF(NINC.NE.1.AND.NINC.NE.2) RETURN
      IF(IOPT.LT.1.OR.IOPT.GT.3) RETURN
C
      GO TO (1000,2000,3000),IOPT
C
C----------  CALC. BY PEARLSTEIN'S SYSTEMATICS  ----------
C
 1000 CONTINUE
C
      AT=FLOAT(IA)
      D1=-2.0
      D2=-2.0
      EE=EX
      IF(EE.GT.1000.0) EE=1000.0

      if(ninc.eq.1) itip=   10
      if(ninc.eq.2) itip=10010

      CALL PNEM2(EE,AT,D1,D2,XSECT,DXSECT,
     &          SIGTOT,SIGNON,SIGELA,DSIGS,ESCAT,ETARG,itip)
c     IF(NINC.EQ.2) SIGTOT=0.0
C
      RETURN
C
C
C----------  CALC. BY NASA SYSTEMATICS  ----------
C
 2000 CONTINUE
C 
      IAP=1
      IZP=1
      IF(NINC.EQ.1) IZP=0
      CALL NASA(IZ,IA,IZP,IAP,EX,SIGTOT,SIGNON)
      SIGELA=SIGTOT-SIGNON
c     IF(NINC.EQ.2) SIGTOT=0.0
C
      RETURN
C
C
C----------  CALC. BY WELLISH'S SYSTEMATICS  ----------
C
 3000 CONTINUE
C
      RZ=FLOAT(IZ)
      RN=FLOAT(IA-IZ)
      ETMP=EX*1.0E-3
      SIGNON=SGREAC(RZ,RN,ETMP)
      SIGNON=SIGNON*1.0E-3
C
      RETURN
      END
