C
C     real*8 function SGREAC
C
C     Reaction Cross Section of proton induced
C
C     H.P.Wellisch & D.Axen,
C         Physical Review C 54, No.3, p.1329 (1996)
C
C     Corrected on Dec. 2,1996
C          by Mail from Wellisch.
C
C* input:
C* rNpro: number of protons in the nucleus = Z
C        ( Z>=5)
C* rNneu: number of neutrons in the nucleus
C* ekin: Kinetic energy of the incoming proton
C        (GeV) (6.8 MeV to 10 GeV)
C* output:
C* xine_th (inelastic cross-secition for p-N scattering.
C
C
C
      real*8 FUNCTION SGREAC(rNPro,rNneu,ekin)
C
      Real*8 r0,pi,a,eekin,fac,b0,fac1,fac2,ff1,ff2,ff3
      real*8 xine_th
C
C* base formula
C
      a=rNneu+rNpro
      eekin=ekin
      r0=1.36d-15
      pi=3.14159265
      fac=pi*r0**2
      b0=2.247d0-0.915d0*(1.0d0-a**(-0.3333))
      fac1=b0*(1.0d0-a**(-0.3333))
      fac2=1.0d0
      if(rNneu.gt.1.5) fac2=log((rNneu))
      xine_th = 1.0d31*fac*fac2*(1.0d0+a**0.3333-fac1)
C
C* high energy correction
c
      xine_th = (1.0d0-0.15d0*exp(-eekin))*xine_th/(1.0d0-0.0007d0*a)
c
C* first try on low energies: rise
C
      ff1= 0.70d0-0.002d0*a
C  ! slope des abfalls bei mittleren energien.
      ff2= 1.00d0+1.0d0/a
C  ! ansatzpunkt des slope.
      ff3= 0.8d0+18.0d0/a-0.002d0*a
C  ! hoehe der Stufe
      fac=1.d0-(1.d0/(1.d0+exp(-8.d0*ff1*(log10(eekin)+1.37d0*ff2))))
      xine_th = xine_th*(1.0d0+ff3*fac)
C
C* low energy return to zero
C
      ff1=1.0d0-1.0d0/a-0.001d0*a
C  ! slope des anstiegs
      ff2=1.17d0-2.7d0/a-0.0014d0*a
C  ! ansatzpunkt des slopes
      fac=-8.0d0*ff1*(log10(eekin)+2.0d0*ff2)
      fac=1.0d0/(1.0d0+exp(fac))
      xine_th = xine_th*fac
c
C
      SGREAC=xine_th
c
      RETURN
      END
